/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output, and Bison version.  */
#define YYBISON 30802

/* Bison version string.  */
#define YYBISON_VERSION "3.8.2"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1




/* First part of user prologue.  */
#line 2 "parse.y"

/*
 * Copyright (c) 2001-2025 Stephen Williams (steve@icarus.com)
 *
 *    This source code is free software; you can redistribute it
 *    and/or modify it in source code form under the terms of the GNU
 *    General Public License as published by the Free Software
 *    Foundation; either version 2 of the License, or (at your option)
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

# include  "parse_misc.h"
# include  "compile.h"
# include  "delay.h"
# include  <list>
# include  <cstdio>
# include  <cstdlib>
# include  <cassert>
# include  "ivl_alloc.h"
# include  "version_base.h"

using namespace std;

/*
 * These are bits in the lexor.
 */
extern FILE*yyin;

vector <const char*> file_names;

/*
 * Local variables.
 */

/*
 * When parsing a modpath list, this is the processed destination that
 * the source items will attach themselves to.
 */
static struct __vpiModPath*modpath_dst = 0;

#line 121 "parse.cc"

# ifndef YY_CAST
#  ifdef __cplusplus
#   define YY_CAST(Type, Val) static_cast<Type> (Val)
#   define YY_REINTERPRET_CAST(Type, Val) reinterpret_cast<Type> (Val)
#  else
#   define YY_CAST(Type, Val) ((Type) (Val))
#   define YY_REINTERPRET_CAST(Type, Val) ((Type) (Val))
#  endif
# endif
# ifndef YY_NULLPTR
#  if defined __cplusplus
#   if 201103L <= __cplusplus
#    define YY_NULLPTR nullptr
#   else
#    define YY_NULLPTR 0
#   endif
#  else
#   define YY_NULLPTR ((void*)0)
#  endif
# endif

#include "parse.h"
/* Symbol kind.  */
enum yysymbol_kind_t
{
  YYSYMBOL_YYEMPTY = -2,
  YYSYMBOL_YYEOF = 0,                      /* "end of file"  */
  YYSYMBOL_YYerror = 1,                    /* error  */
  YYSYMBOL_YYUNDEF = 2,                    /* "invalid token"  */
  YYSYMBOL_K_A = 3,                        /* K_A  */
  YYSYMBOL_K_APV = 4,                      /* K_APV  */
  YYSYMBOL_K_ARITH_ABS = 5,                /* K_ARITH_ABS  */
  YYSYMBOL_K_ARITH_DIV = 6,                /* K_ARITH_DIV  */
  YYSYMBOL_K_ARITH_DIV_R = 7,              /* K_ARITH_DIV_R  */
  YYSYMBOL_K_ARITH_DIV_S = 8,              /* K_ARITH_DIV_S  */
  YYSYMBOL_K_ARITH_MOD = 9,                /* K_ARITH_MOD  */
  YYSYMBOL_K_ARITH_MOD_R = 10,             /* K_ARITH_MOD_R  */
  YYSYMBOL_K_ARITH_MOD_S = 11,             /* K_ARITH_MOD_S  */
  YYSYMBOL_K_ARITH_MULT = 12,              /* K_ARITH_MULT  */
  YYSYMBOL_K_ARITH_MULT_R = 13,            /* K_ARITH_MULT_R  */
  YYSYMBOL_K_ARITH_SUB = 14,               /* K_ARITH_SUB  */
  YYSYMBOL_K_ARITH_SUB_R = 15,             /* K_ARITH_SUB_R  */
  YYSYMBOL_K_ARITH_SUM = 16,               /* K_ARITH_SUM  */
  YYSYMBOL_K_ARITH_SUM_R = 17,             /* K_ARITH_SUM_R  */
  YYSYMBOL_K_ARITH_POW = 18,               /* K_ARITH_POW  */
  YYSYMBOL_K_ARITH_POW_R = 19,             /* K_ARITH_POW_R  */
  YYSYMBOL_K_ARITH_POW_S = 20,             /* K_ARITH_POW_S  */
  YYSYMBOL_K_ARRAY = 21,                   /* K_ARRAY  */
  YYSYMBOL_K_ARRAY_2U = 22,                /* K_ARRAY_2U  */
  YYSYMBOL_K_ARRAY_2S = 23,                /* K_ARRAY_2S  */
  YYSYMBOL_K_ARRAY_I = 24,                 /* K_ARRAY_I  */
  YYSYMBOL_K_ARRAY_OBJ = 25,               /* K_ARRAY_OBJ  */
  YYSYMBOL_K_ARRAY_R = 26,                 /* K_ARRAY_R  */
  YYSYMBOL_K_ARRAY_S = 27,                 /* K_ARRAY_S  */
  YYSYMBOL_K_ARRAY_STR = 28,               /* K_ARRAY_STR  */
  YYSYMBOL_K_ARRAY_PORT = 29,              /* K_ARRAY_PORT  */
  YYSYMBOL_K_CAST_INT = 30,                /* K_CAST_INT  */
  YYSYMBOL_K_CAST_REAL = 31,               /* K_CAST_REAL  */
  YYSYMBOL_K_CAST_REAL_S = 32,             /* K_CAST_REAL_S  */
  YYSYMBOL_K_CAST_2 = 33,                  /* K_CAST_2  */
  YYSYMBOL_K_CLASS = 34,                   /* K_CLASS  */
  YYSYMBOL_K_CMP_EEQ = 35,                 /* K_CMP_EEQ  */
  YYSYMBOL_K_CMP_EQ = 36,                  /* K_CMP_EQ  */
  YYSYMBOL_K_CMP_EQX = 37,                 /* K_CMP_EQX  */
  YYSYMBOL_K_CMP_EQZ = 38,                 /* K_CMP_EQZ  */
  YYSYMBOL_K_CMP_WEQ = 39,                 /* K_CMP_WEQ  */
  YYSYMBOL_K_CMP_WNE = 40,                 /* K_CMP_WNE  */
  YYSYMBOL_K_CMP_EQ_R = 41,                /* K_CMP_EQ_R  */
  YYSYMBOL_K_CMP_NEE = 42,                 /* K_CMP_NEE  */
  YYSYMBOL_K_CMP_NE = 43,                  /* K_CMP_NE  */
  YYSYMBOL_K_CMP_NE_R = 44,                /* K_CMP_NE_R  */
  YYSYMBOL_K_CMP_GE = 45,                  /* K_CMP_GE  */
  YYSYMBOL_K_CMP_GE_R = 46,                /* K_CMP_GE_R  */
  YYSYMBOL_K_CMP_GE_S = 47,                /* K_CMP_GE_S  */
  YYSYMBOL_K_CMP_GT = 48,                  /* K_CMP_GT  */
  YYSYMBOL_K_CMP_GT_R = 49,                /* K_CMP_GT_R  */
  YYSYMBOL_K_CMP_GT_S = 50,                /* K_CMP_GT_S  */
  YYSYMBOL_K_CONCAT = 51,                  /* K_CONCAT  */
  YYSYMBOL_K_CONCAT8 = 52,                 /* K_CONCAT8  */
  YYSYMBOL_K_DEBUG = 53,                   /* K_DEBUG  */
  YYSYMBOL_K_DELAY = 54,                   /* K_DELAY  */
  YYSYMBOL_K_DFF_N = 55,                   /* K_DFF_N  */
  YYSYMBOL_K_DFF_N_ACLR = 56,              /* K_DFF_N_ACLR  */
  YYSYMBOL_K_DFF_N_ASET = 57,              /* K_DFF_N_ASET  */
  YYSYMBOL_K_DFF_P = 58,                   /* K_DFF_P  */
  YYSYMBOL_K_DFF_P_ACLR = 59,              /* K_DFF_P_ACLR  */
  YYSYMBOL_K_DFF_P_ASET = 60,              /* K_DFF_P_ASET  */
  YYSYMBOL_K_ENUM2 = 61,                   /* K_ENUM2  */
  YYSYMBOL_K_ENUM2_S = 62,                 /* K_ENUM2_S  */
  YYSYMBOL_K_ENUM4 = 63,                   /* K_ENUM4  */
  YYSYMBOL_K_ENUM4_S = 64,                 /* K_ENUM4_S  */
  YYSYMBOL_K_EVENT = 65,                   /* K_EVENT  */
  YYSYMBOL_K_EVENT_OR = 66,                /* K_EVENT_OR  */
  YYSYMBOL_K_EXPORT = 67,                  /* K_EXPORT  */
  YYSYMBOL_K_EXTEND_S = 68,                /* K_EXTEND_S  */
  YYSYMBOL_K_FUNCTOR = 69,                 /* K_FUNCTOR  */
  YYSYMBOL_K_IMPORT = 70,                  /* K_IMPORT  */
  YYSYMBOL_K_ISLAND = 71,                  /* K_ISLAND  */
  YYSYMBOL_K_LATCH = 72,                   /* K_LATCH  */
  YYSYMBOL_K_MODPATH = 73,                 /* K_MODPATH  */
  YYSYMBOL_K_NET = 74,                     /* K_NET  */
  YYSYMBOL_K_NET_S = 75,                   /* K_NET_S  */
  YYSYMBOL_K_NET_R = 76,                   /* K_NET_R  */
  YYSYMBOL_K_NET_2S = 77,                  /* K_NET_2S  */
  YYSYMBOL_K_NET_2U = 78,                  /* K_NET_2U  */
  YYSYMBOL_K_NET8 = 79,                    /* K_NET8  */
  YYSYMBOL_K_NET8_2S = 80,                 /* K_NET8_2S  */
  YYSYMBOL_K_NET8_2U = 81,                 /* K_NET8_2U  */
  YYSYMBOL_K_NET8_S = 82,                  /* K_NET8_S  */
  YYSYMBOL_K_PARAM_STR = 83,               /* K_PARAM_STR  */
  YYSYMBOL_K_PARAM_L = 84,                 /* K_PARAM_L  */
  YYSYMBOL_K_PARAM_REAL = 85,              /* K_PARAM_REAL  */
  YYSYMBOL_K_PART = 86,                    /* K_PART  */
  YYSYMBOL_K_PART_PV = 87,                 /* K_PART_PV  */
  YYSYMBOL_K_PART_V = 88,                  /* K_PART_V  */
  YYSYMBOL_K_PART_V_S = 89,                /* K_PART_V_S  */
  YYSYMBOL_K_PORT = 90,                    /* K_PORT  */
  YYSYMBOL_K_PORT_INFO = 91,               /* K_PORT_INFO  */
  YYSYMBOL_K_PV = 92,                      /* K_PV  */
  YYSYMBOL_K_REDUCE_AND = 93,              /* K_REDUCE_AND  */
  YYSYMBOL_K_REDUCE_OR = 94,               /* K_REDUCE_OR  */
  YYSYMBOL_K_REDUCE_XOR = 95,              /* K_REDUCE_XOR  */
  YYSYMBOL_K_REDUCE_NAND = 96,             /* K_REDUCE_NAND  */
  YYSYMBOL_K_REDUCE_NOR = 97,              /* K_REDUCE_NOR  */
  YYSYMBOL_K_REDUCE_XNOR = 98,             /* K_REDUCE_XNOR  */
  YYSYMBOL_K_REPEAT = 99,                  /* K_REPEAT  */
  YYSYMBOL_K_RESOLV = 100,                 /* K_RESOLV  */
  YYSYMBOL_K_RTRAN = 101,                  /* K_RTRAN  */
  YYSYMBOL_K_RTRANIF0 = 102,               /* K_RTRANIF0  */
  YYSYMBOL_K_RTRANIF1 = 103,               /* K_RTRANIF1  */
  YYSYMBOL_K_SCOPE = 104,                  /* K_SCOPE  */
  YYSYMBOL_K_SFUNC = 105,                  /* K_SFUNC  */
  YYSYMBOL_K_SFUNC_E = 106,                /* K_SFUNC_E  */
  YYSYMBOL_K_SHIFTL = 107,                 /* K_SHIFTL  */
  YYSYMBOL_K_SHIFTR = 108,                 /* K_SHIFTR  */
  YYSYMBOL_K_SHIFTRS = 109,                /* K_SHIFTRS  */
  YYSYMBOL_K_SUBSTITUTE = 110,             /* K_SUBSTITUTE  */
  YYSYMBOL_K_THREAD = 111,                 /* K_THREAD  */
  YYSYMBOL_K_TIMESCALE = 112,              /* K_TIMESCALE  */
  YYSYMBOL_K_TRAN = 113,                   /* K_TRAN  */
  YYSYMBOL_K_TRANIF0 = 114,                /* K_TRANIF0  */
  YYSYMBOL_K_TRANIF1 = 115,                /* K_TRANIF1  */
  YYSYMBOL_K_TRANVP = 116,                 /* K_TRANVP  */
  YYSYMBOL_K_UFUNC_REAL = 117,             /* K_UFUNC_REAL  */
  YYSYMBOL_K_UFUNC_VEC4 = 118,             /* K_UFUNC_VEC4  */
  YYSYMBOL_K_UFUNC_E = 119,                /* K_UFUNC_E  */
  YYSYMBOL_K_UDP = 120,                    /* K_UDP  */
  YYSYMBOL_K_UDP_C = 121,                  /* K_UDP_C  */
  YYSYMBOL_K_UDP_S = 122,                  /* K_UDP_S  */
  YYSYMBOL_K_VAR = 123,                    /* K_VAR  */
  YYSYMBOL_K_VAR_COBJECT = 124,            /* K_VAR_COBJECT  */
  YYSYMBOL_K_VAR_DARRAY = 125,             /* K_VAR_DARRAY  */
  YYSYMBOL_K_VAR_QUEUE = 126,              /* K_VAR_QUEUE  */
  YYSYMBOL_K_VAR_S = 127,                  /* K_VAR_S  */
  YYSYMBOL_K_VAR_STR = 128,                /* K_VAR_STR  */
  YYSYMBOL_K_VAR_I = 129,                  /* K_VAR_I  */
  YYSYMBOL_K_VAR_R = 130,                  /* K_VAR_R  */
  YYSYMBOL_K_VAR_2S = 131,                 /* K_VAR_2S  */
  YYSYMBOL_K_VAR_2U = 132,                 /* K_VAR_2U  */
  YYSYMBOL_K_vpi_call = 133,               /* K_vpi_call  */
  YYSYMBOL_K_vpi_call_w = 134,             /* K_vpi_call_w  */
  YYSYMBOL_K_vpi_call_i = 135,             /* K_vpi_call_i  */
  YYSYMBOL_K_vpi_func = 136,               /* K_vpi_func  */
  YYSYMBOL_K_vpi_func_r = 137,             /* K_vpi_func_r  */
  YYSYMBOL_K_vpi_func_s = 138,             /* K_vpi_func_s  */
  YYSYMBOL_K_ivl_version = 139,            /* K_ivl_version  */
  YYSYMBOL_K_ivl_delay_selection = 140,    /* K_ivl_delay_selection  */
  YYSYMBOL_K_vpi_module = 141,             /* K_vpi_module  */
  YYSYMBOL_K_vpi_time_precision = 142,     /* K_vpi_time_precision  */
  YYSYMBOL_K_file_names = 143,             /* K_file_names  */
  YYSYMBOL_K_file_line = 144,              /* K_file_line  */
  YYSYMBOL_K_PORT_INPUT = 145,             /* K_PORT_INPUT  */
  YYSYMBOL_K_PORT_OUTPUT = 146,            /* K_PORT_OUTPUT  */
  YYSYMBOL_K_PORT_INOUT = 147,             /* K_PORT_INOUT  */
  YYSYMBOL_K_PORT_MIXED = 148,             /* K_PORT_MIXED  */
  YYSYMBOL_K_PORT_NODIR = 149,             /* K_PORT_NODIR  */
  YYSYMBOL_T_INSTR = 150,                  /* T_INSTR  */
  YYSYMBOL_T_LABEL = 151,                  /* T_LABEL  */
  YYSYMBOL_T_NUMBER = 152,                 /* T_NUMBER  */
  YYSYMBOL_T_STRING = 153,                 /* T_STRING  */
  YYSYMBOL_T_SYMBOL = 154,                 /* T_SYMBOL  */
  YYSYMBOL_T_VECTOR = 155,                 /* T_VECTOR  */
  YYSYMBOL_156_ = 156,                     /* ';'  */
  YYSYMBOL_157_ = 157,                     /* '+'  */
  YYSYMBOL_158_ = 158,                     /* '-'  */
  YYSYMBOL_159_ = 159,                     /* ','  */
  YYSYMBOL_160_ = 160,                     /* '['  */
  YYSYMBOL_161_ = 161,                     /* ']'  */
  YYSYMBOL_162_ = 162,                     /* '('  */
  YYSYMBOL_163_ = 163,                     /* ')'  */
  YYSYMBOL_164_ = 164,                     /* '{'  */
  YYSYMBOL_165_ = 165,                     /* '}'  */
  YYSYMBOL_166_ = 166,                     /* ':'  */
  YYSYMBOL_167_ = 167,                     /* '*'  */
  YYSYMBOL_168_ = 168,                     /* '<'  */
  YYSYMBOL_169_ = 169,                     /* '>'  */
  YYSYMBOL_170_ = 170,                     /* '?'  */
  YYSYMBOL_YYACCEPT = 171,                 /* $accept  */
  YYSYMBOL_source_file = 172,              /* source_file  */
  YYSYMBOL_header_lines_opt = 173,         /* header_lines_opt  */
  YYSYMBOL_header_lines = 174,             /* header_lines  */
  YYSYMBOL_header_line = 175,              /* header_line  */
  YYSYMBOL_footer_lines = 176,             /* footer_lines  */
  YYSYMBOL_177_1 = 177,                    /* $@1  */
  YYSYMBOL_name_strings = 178,             /* name_strings  */
  YYSYMBOL_program = 179,                  /* program  */
  YYSYMBOL_statement = 180,                /* statement  */
  YYSYMBOL_181_2 = 181,                    /* $@2  */
  YYSYMBOL_182_3 = 182,                    /* $@3  */
  YYSYMBOL_class_properties_opt = 183,     /* class_properties_opt  */
  YYSYMBOL_class_properties = 184,         /* class_properties  */
  YYSYMBOL_class_property = 185,           /* class_property  */
  YYSYMBOL_dimensions_opt = 186,           /* dimensions_opt  */
  YYSYMBOL_dimensions = 187,               /* dimensions  */
  YYSYMBOL_dimension = 188,                /* dimension  */
  YYSYMBOL_enum_type = 189,                /* enum_type  */
  YYSYMBOL_enum_type_names = 190,          /* enum_type_names  */
  YYSYMBOL_enum_type_name = 191,           /* enum_type_name  */
  YYSYMBOL_local_flag = 192,               /* local_flag  */
  YYSYMBOL_label_opt = 193,                /* label_opt  */
  YYSYMBOL_operands_opt = 194,             /* operands_opt  */
  YYSYMBOL_operands = 195,                 /* operands  */
  YYSYMBOL_operand = 196,                  /* operand  */
  YYSYMBOL_argument_opt = 197,             /* argument_opt  */
  YYSYMBOL_argument_list = 198,            /* argument_list  */
  YYSYMBOL_argument = 199,                 /* argument  */
  YYSYMBOL_symbol_access = 200,            /* symbol_access  */
  YYSYMBOL_symbols = 201,                  /* symbols  */
  YYSYMBOL_numbers = 202,                  /* numbers  */
  YYSYMBOL_symbols_net = 203,              /* symbols_net  */
  YYSYMBOL_symbol = 204,                   /* symbol  */
  YYSYMBOL_symbol_opt = 205,               /* symbol_opt  */
  YYSYMBOL_modpath_src_list = 206,         /* modpath_src_list  */
  YYSYMBOL_port_type = 207,                /* port_type  */
  YYSYMBOL_modpath_src = 208,              /* modpath_src  */
  YYSYMBOL_udp_table = 209,                /* udp_table  */
  YYSYMBOL_signed_t_number = 210,          /* signed_t_number  */
  YYSYMBOL_delay = 211                     /* delay  */
};
typedef enum yysymbol_kind_t yysymbol_kind_t;




#ifdef short
# undef short
#endif

/* On compilers that do not define __PTRDIFF_MAX__ etc., make sure
   <limits.h> and (if available) <stdint.h> are included
   so that the code can choose integer types of a good width.  */

#ifndef __PTRDIFF_MAX__
# include <limits.h> /* INFRINGES ON USER NAME SPACE */
# if defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stdint.h> /* INFRINGES ON USER NAME SPACE */
#  define YY_STDINT_H
# endif
#endif

/* Narrow types that promote to a signed type and that can represent a
   signed or unsigned integer of at least N bits.  In tables they can
   save space and decrease cache pressure.  Promoting to a signed type
   helps avoid bugs in integer arithmetic.  */

#ifdef __INT_LEAST8_MAX__
typedef __INT_LEAST8_TYPE__ yytype_int8;
#elif defined YY_STDINT_H
typedef int_least8_t yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef __INT_LEAST16_MAX__
typedef __INT_LEAST16_TYPE__ yytype_int16;
#elif defined YY_STDINT_H
typedef int_least16_t yytype_int16;
#else
typedef short yytype_int16;
#endif

/* Work around bug in HP-UX 11.23, which defines these macros
   incorrectly for preprocessor constants.  This workaround can likely
   be removed in 2023, as HPE has promised support for HP-UX 11.23
   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
#ifdef __hpux
# undef UINT_LEAST8_MAX
# undef UINT_LEAST16_MAX
# define UINT_LEAST8_MAX 255
# define UINT_LEAST16_MAX 65535
#endif

#if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
typedef __UINT_LEAST8_TYPE__ yytype_uint8;
#elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST8_MAX <= INT_MAX)
typedef uint_least8_t yytype_uint8;
#elif !defined __UINT_LEAST8_MAX__ && UCHAR_MAX <= INT_MAX
typedef unsigned char yytype_uint8;
#else
typedef short yytype_uint8;
#endif

#if defined __UINT_LEAST16_MAX__ && __UINT_LEAST16_MAX__ <= __INT_MAX__
typedef __UINT_LEAST16_TYPE__ yytype_uint16;
#elif (!defined __UINT_LEAST16_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST16_MAX <= INT_MAX)
typedef uint_least16_t yytype_uint16;
#elif !defined __UINT_LEAST16_MAX__ && USHRT_MAX <= INT_MAX
typedef unsigned short yytype_uint16;
#else
typedef int yytype_uint16;
#endif

#ifndef YYPTRDIFF_T
# if defined __PTRDIFF_TYPE__ && defined __PTRDIFF_MAX__
#  define YYPTRDIFF_T __PTRDIFF_TYPE__
#  define YYPTRDIFF_MAXIMUM __PTRDIFF_MAX__
# elif defined PTRDIFF_MAX
#  ifndef ptrdiff_t
#   include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  endif
#  define YYPTRDIFF_T ptrdiff_t
#  define YYPTRDIFF_MAXIMUM PTRDIFF_MAX
# else
#  define YYPTRDIFF_T long
#  define YYPTRDIFF_MAXIMUM LONG_MAX
# endif
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned
# endif
#endif

#define YYSIZE_MAXIMUM                                  \
  YY_CAST (YYPTRDIFF_T,                                 \
           (YYPTRDIFF_MAXIMUM < YY_CAST (YYSIZE_T, -1)  \
            ? YYPTRDIFF_MAXIMUM                         \
            : YY_CAST (YYSIZE_T, -1)))

#define YYSIZEOF(X) YY_CAST (YYPTRDIFF_T, sizeof (X))


/* Stored state numbers (used for stacks). */
typedef yytype_int16 yy_state_t;

/* State numbers in computations.  */
typedef int yy_state_fast_t;

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif


#ifndef YY_ATTRIBUTE_PURE
# if defined __GNUC__ && 2 < __GNUC__ + (96 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_PURE __attribute__ ((__pure__))
# else
#  define YY_ATTRIBUTE_PURE
# endif
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# if defined __GNUC__ && 2 < __GNUC__ + (7 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_UNUSED __attribute__ ((__unused__))
# else
#  define YY_ATTRIBUTE_UNUSED
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YY_USE(E) ((void) (E))
#else
# define YY_USE(E) /* empty */
#endif

/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
# else
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# endif
# define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif

#if defined __cplusplus && defined __GNUC__ && ! defined __ICC && 6 <= __GNUC__
# define YY_IGNORE_USELESS_CAST_BEGIN                          \
    _Pragma ("GCC diagnostic push")                            \
    _Pragma ("GCC diagnostic ignored \"-Wuseless-cast\"")
# define YY_IGNORE_USELESS_CAST_END            \
    _Pragma ("GCC diagnostic pop")
#endif
#ifndef YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_END
#endif


#define YY_ASSERT(E) ((void) (0 && (E)))

#if !defined yyoverflow

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* !defined yyoverflow */

#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yy_state_t yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (YYSIZEOF (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (YYSIZEOF (yy_state_t) + YYSIZEOF (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYPTRDIFF_T yynewbytes;                                         \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * YYSIZEOF (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / YYSIZEOF (*yyptr);                        \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, YY_CAST (YYSIZE_T, (Count)) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYPTRDIFF_T yyi;                      \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  14
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   1298

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  171
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  41
/* YYNRULES -- Number of rules.  */
#define YYNRULES  261
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  1189

/* YYMAXUTOK -- Last valid token kind.  */
#define YYMAXUTOK   410


/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, with out-of-bounds checking.  */
#define YYTRANSLATE(YYX)                                \
  (0 <= (YYX) && (YYX) <= YYMAXUTOK                     \
   ? YY_CAST (yysymbol_kind_t, yytranslate[YYX])        \
   : YYSYMBOL_YYUNDEF)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     162,   163,   167,   157,   159,   158,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,   166,   156,
     168,     2,   169,   170,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,   160,     2,   161,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,   164,     2,   165,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,    68,    69,    70,    71,    72,    73,    74,
      75,    76,    77,    78,    79,    80,    81,    82,    83,    84,
      85,    86,    87,    88,    89,    90,    91,    92,    93,    94,
      95,    96,    97,    98,    99,   100,   101,   102,   103,   104,
     105,   106,   107,   108,   109,   110,   111,   112,   113,   114,
     115,   116,   117,   118,   119,   120,   121,   122,   123,   124,
     125,   126,   127,   128,   129,   130,   131,   132,   133,   134,
     135,   136,   137,   138,   139,   140,   141,   142,   143,   144,
     145,   146,   147,   148,   149,   150,   151,   152,   153,   154,
     155
};

#if YYDEBUG
/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_int16 yyrline[] =
{
       0,   139,   139,   141,   141,   145,   146,   150,   152,   154,
     156,   158,   160,   165,   165,   170,   172,   178,   179,   194,
     197,   210,   213,   216,   222,   225,   227,   230,   233,   236,
     239,   242,   245,   248,   251,   254,   261,   263,   266,   268,
     271,   277,   285,   288,   291,   293,   298,   302,   307,   313,
     318,   323,   328,   333,   341,   346,   351,   356,   361,   366,
     371,   376,   381,   386,   391,   396,   401,   406,   411,   416,
     421,   426,   431,   436,   441,   446,   451,   456,   461,   466,
     471,   476,   481,   486,   491,   500,   502,   506,   513,   512,
     519,   522,   525,   528,   531,   534,   537,   540,   545,   550,
     553,   556,   559,   562,   565,   568,   573,   577,   581,   586,
     590,   596,   601,   607,   617,   620,   623,   626,   634,   637,
     642,   645,   655,   662,   669,   674,   679,   684,   704,   707,
     714,   720,   724,   728,   730,   732,   734,   741,   744,   751,
     754,   757,   760,   763,   766,   769,   772,   775,   778,   784,
     788,   792,   796,   800,   804,   808,   812,   816,   822,   826,
     830,   834,   838,   842,   846,   853,   856,   859,   862,   867,
     870,   873,   876,   879,   882,   885,   888,   891,   894,   897,
     903,   902,   907,   912,   916,   917,   921,   922,   926,   937,
     939,   943,   945,   950,   956,   958,   960,   962,   967,   972,
     980,   982,   987,   988,   995,   996,  1000,  1001,  1005,  1014,
    1019,  1027,  1035,  1060,  1066,  1073,  1079,  1084,  1090,  1098,
    1100,  1104,  1109,  1111,  1113,  1115,  1117,  1119,  1121,  1123,
    1129,  1135,  1144,  1150,  1159,  1165,  1177,  1184,  1187,  1197,
    1198,  1202,  1203,  1204,  1205,  1206,  1210,  1212,  1214,  1216,
    1218,  1220,  1222,  1224,  1226,  1231,  1233,  1238,  1239,  1243,
    1245,  1247
};
#endif

/** Accessing symbol of state STATE.  */
#define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])

#if YYDEBUG || 0
/* The user-facing name of the symbol whose (internal) number is
   YYSYMBOL.  No bounds checking.  */
static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;

/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "\"end of file\"", "error", "\"invalid token\"", "K_A", "K_APV",
  "K_ARITH_ABS", "K_ARITH_DIV", "K_ARITH_DIV_R", "K_ARITH_DIV_S",
  "K_ARITH_MOD", "K_ARITH_MOD_R", "K_ARITH_MOD_S", "K_ARITH_MULT",
  "K_ARITH_MULT_R", "K_ARITH_SUB", "K_ARITH_SUB_R", "K_ARITH_SUM",
  "K_ARITH_SUM_R", "K_ARITH_POW", "K_ARITH_POW_R", "K_ARITH_POW_S",
  "K_ARRAY", "K_ARRAY_2U", "K_ARRAY_2S", "K_ARRAY_I", "K_ARRAY_OBJ",
  "K_ARRAY_R", "K_ARRAY_S", "K_ARRAY_STR", "K_ARRAY_PORT", "K_CAST_INT",
  "K_CAST_REAL", "K_CAST_REAL_S", "K_CAST_2", "K_CLASS", "K_CMP_EEQ",
  "K_CMP_EQ", "K_CMP_EQX", "K_CMP_EQZ", "K_CMP_WEQ", "K_CMP_WNE",
  "K_CMP_EQ_R", "K_CMP_NEE", "K_CMP_NE", "K_CMP_NE_R", "K_CMP_GE",
  "K_CMP_GE_R", "K_CMP_GE_S", "K_CMP_GT", "K_CMP_GT_R", "K_CMP_GT_S",
  "K_CONCAT", "K_CONCAT8", "K_DEBUG", "K_DELAY", "K_DFF_N", "K_DFF_N_ACLR",
  "K_DFF_N_ASET", "K_DFF_P", "K_DFF_P_ACLR", "K_DFF_P_ASET", "K_ENUM2",
  "K_ENUM2_S", "K_ENUM4", "K_ENUM4_S", "K_EVENT", "K_EVENT_OR", "K_EXPORT",
  "K_EXTEND_S", "K_FUNCTOR", "K_IMPORT", "K_ISLAND", "K_LATCH",
  "K_MODPATH", "K_NET", "K_NET_S", "K_NET_R", "K_NET_2S", "K_NET_2U",
  "K_NET8", "K_NET8_2S", "K_NET8_2U", "K_NET8_S", "K_PARAM_STR",
  "K_PARAM_L", "K_PARAM_REAL", "K_PART", "K_PART_PV", "K_PART_V",
  "K_PART_V_S", "K_PORT", "K_PORT_INFO", "K_PV", "K_REDUCE_AND",
  "K_REDUCE_OR", "K_REDUCE_XOR", "K_REDUCE_NAND", "K_REDUCE_NOR",
  "K_REDUCE_XNOR", "K_REPEAT", "K_RESOLV", "K_RTRAN", "K_RTRANIF0",
  "K_RTRANIF1", "K_SCOPE", "K_SFUNC", "K_SFUNC_E", "K_SHIFTL", "K_SHIFTR",
  "K_SHIFTRS", "K_SUBSTITUTE", "K_THREAD", "K_TIMESCALE", "K_TRAN",
  "K_TRANIF0", "K_TRANIF1", "K_TRANVP", "K_UFUNC_REAL", "K_UFUNC_VEC4",
  "K_UFUNC_E", "K_UDP", "K_UDP_C", "K_UDP_S", "K_VAR", "K_VAR_COBJECT",
  "K_VAR_DARRAY", "K_VAR_QUEUE", "K_VAR_S", "K_VAR_STR", "K_VAR_I",
  "K_VAR_R", "K_VAR_2S", "K_VAR_2U", "K_vpi_call", "K_vpi_call_w",
  "K_vpi_call_i", "K_vpi_func", "K_vpi_func_r", "K_vpi_func_s",
  "K_ivl_version", "K_ivl_delay_selection", "K_vpi_module",
  "K_vpi_time_precision", "K_file_names", "K_file_line", "K_PORT_INPUT",
  "K_PORT_OUTPUT", "K_PORT_INOUT", "K_PORT_MIXED", "K_PORT_NODIR",
  "T_INSTR", "T_LABEL", "T_NUMBER", "T_STRING", "T_SYMBOL", "T_VECTOR",
  "';'", "'+'", "'-'", "','", "'['", "']'", "'('", "')'", "'{'", "'}'",
  "':'", "'*'", "'<'", "'>'", "'?'", "$accept", "source_file",
  "header_lines_opt", "header_lines", "header_line", "footer_lines", "$@1",
  "name_strings", "program", "statement", "$@2", "$@3",
  "class_properties_opt", "class_properties", "class_property",
  "dimensions_opt", "dimensions", "dimension", "enum_type",
  "enum_type_names", "enum_type_name", "local_flag", "label_opt",
  "operands_opt", "operands", "operand", "argument_opt", "argument_list",
  "argument", "symbol_access", "symbols", "numbers", "symbols_net",
  "symbol", "symbol_opt", "modpath_src_list", "port_type", "modpath_src",
  "udp_table", "signed_t_number", "delay", YY_NULLPTR
};

static const char *
yysymbol_name (yysymbol_kind_t yysymbol)
{
  return yytname[yysymbol];
}
#endif

#define YYPACT_NINF (-710)

#define yypact_value_is_default(Yyn) \
  ((Yyn) == YYPACT_NINF)

#define YYTABLE_NINF (-1)

#define yytable_value_is_error(Yyn) \
  0

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
static const yytype_int16 yypact[] =
{
      45,  -142,  -113,   -49,   -99,    29,   -48,    45,  -710,   -72,
     -74,   -62,   -25,     4,  -710,    25,    -7,    27,   142,   173,
     204,   -65,   211,   232,   244,   116,  1031,  -710,   -66,  -710,
    -710,   -64,  -710,   164,  -710,  -710,  -710,   247,   253,    23,
     262,   317,   325,   332,    -5,   -46,   337,   331,   333,   334,
     339,   340,   343,   344,   345,   346,   347,   348,   349,   350,
     351,   352,   353,   354,   355,   356,   357,   359,   360,   362,
     363,   364,   365,   366,   367,   368,   358,   340,   340,   369,
     370,   372,   373,   374,   375,   376,   377,   378,   379,   380,
     381,   382,   383,   384,   385,   386,   387,   388,   389,   390,
     391,   392,   393,   394,   395,   398,   396,   397,   399,   400,
     -43,   340,   401,   402,   403,   406,   409,   404,   412,  -139,
    -134,  -133,  -123,   -92,   -78,   405,   405,   -76,   413,   414,
     415,   411,   416,   417,   419,   420,   340,   340,   340,   340,
     340,   340,   423,   422,   424,   425,   427,   444,   445,   446,
     447,   448,   449,   450,   452,   454,   455,   405,   456,   457,
     458,   405,   459,   405,   460,   405,   405,  -710,   462,  -710,
    -710,   463,   464,   465,   466,   468,   469,   471,   -39,  -710,
    -710,  -710,  -710,  -710,  -710,  -710,  -710,   472,   473,   474,
     475,  -710,  -710,   476,   477,   479,   -29,   478,   480,   481,
     484,  -710,    20,  -710,   410,   441,   442,   482,   483,   485,
     490,   491,   493,   494,   495,   496,   497,   498,   499,   506,
     507,   508,   509,   510,   511,   512,   513,   514,   515,    32,
      52,   516,   517,   519,   520,   521,   522,   523,   524,   525,
     526,   527,   528,   529,   530,   531,   534,   535,   536,   486,
     487,  -140,   340,   340,   340,   340,   340,   340,   488,   544,
     545,   546,   489,   543,   541,    53,   547,   542,   550,   548,
     549,   340,   340,   552,  -710,   553,   556,   557,   559,   560,
     562,   563,   565,   566,   568,   569,   570,   571,   573,   574,
     576,   577,   578,   567,   572,   575,   579,   580,   581,   589,
     590,   591,   592,   593,   594,   595,   596,   583,   584,   597,
     598,   599,   600,   601,   602,   603,   604,   605,   623,   630,
     628,   626,   627,   634,   632,   636,   631,   638,   639,   637,
     642,   643,   644,   645,   646,   647,   648,  -710,  -710,   649,
     650,  -710,  -710,   651,   555,   558,   561,   652,  -710,   654,
     655,   660,   564,   653,   659,   656,  -710,   340,   340,   340,
     340,   340,   340,   340,   340,   340,   340,   340,   340,   340,
     340,   340,   340,   -30,   -27,   -27,   -27,   -27,   -27,   -27,
     -27,    21,   340,  -710,  -710,   340,   662,   340,   340,   340,
     340,   340,   340,   340,   340,   340,   340,   340,   340,   340,
     340,   340,   340,   664,   665,   666,    54,   340,   661,   663,
     667,   668,   669,   670,   587,   588,   640,   658,   671,  -710,
     340,  -710,  -710,   340,    30,   677,  -710,   675,   340,   678,
     679,   680,   681,   682,   684,   685,   686,   687,   688,   689,
     690,   691,   692,   693,   694,   672,   673,   702,   703,   704,
     705,   706,   707,  -710,  -710,  -710,  -710,  -710,  -710,   710,
     340,   711,   712,   713,   340,   340,   340,   715,   716,   718,
     719,   340,   720,   722,   698,  -710,   725,   726,   699,  -710,
     721,   -27,   723,   724,  -710,   728,   731,   732,   733,   734,
     735,   285,  -710,   -39,    80,   736,   730,   737,  -710,  -710,
    -710,   738,   739,   740,   741,   709,  -710,    58,    59,    60,
      64,    66,    68,    70,    72,    74,    76,    88,    89,    90,
      94,    95,  -710,   742,   727,   -27,   -27,   -27,   -27,   -27,
     -27,   -27,   -27,   745,   746,    96,   100,   641,   101,   102,
     106,   107,   108,   113,   114,   118,   119,   120,   124,   125,
     126,   130,   132,   134,   751,   752,  -102,  -710,   250,   753,
     340,   340,   340,   340,   340,   340,   744,   744,   744,   744,
     340,   138,   754,   340,   755,   756,   340,   757,   -27,   -27,
     -27,   -27,   -27,   -27,   -27,   -27,   -27,   -27,   -27,   -27,
     -27,   -27,   -27,   -27,   759,   761,   763,   758,   760,   762,
     764,   766,   765,   139,   767,   768,   769,   158,   159,   160,
     773,   770,   771,   772,   165,   774,   775,   -27,   776,   779,
     -27,   784,   -27,   -27,   -27,   785,   778,   778,   778,   787,
     778,   778,   786,   788,  -710,   789,  -710,  -710,   792,   793,
    -710,  -710,   794,   795,   781,  -710,  -710,  -710,  -710,  -710,
    -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,
    -710,  -710,   166,   782,   791,   796,   797,   798,   799,   803,
    -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,
    -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,
    -710,   800,   808,   809,  -710,   806,  -710,   804,   805,   807,
     810,   811,   812,   193,   190,  -710,   191,   195,   196,   197,
    -710,  -710,   203,   813,  -710,   816,  -710,   -27,   -27,   -27,
     -27,   -27,   -27,   -27,   -27,   -27,   -27,   -27,   -27,   -27,
     -27,   -27,   -27,   814,   815,   817,   823,   825,   826,   827,
    -710,   340,  -710,   828,   790,   831,  -710,  -710,  -710,   829,
     832,   835,   836,  -710,   838,   840,   -27,  -710,  -710,   -27,
     841,   839,   -27,   -27,   842,   843,     5,   729,   830,   833,
     778,   837,   844,  -710,  -710,  -710,   846,   847,   848,   849,
     845,  -710,   -27,   -27,   -27,   -27,  -710,  -710,   -27,  -710,
     855,   850,   851,   -80,  -710,   340,   340,   340,   340,   340,
     340,  -710,  -710,  -710,   744,  -710,  -710,  -710,  -710,  -710,
     852,  -710,   340,   857,   858,   860,   861,   863,   864,   865,
     866,   867,   868,   869,   870,   871,   872,   873,   875,   931,
     206,   856,   966,   964,   976,   977,   978,   862,   208,   983,
     340,   987,   207,   988,   209,   986,  -710,   214,  1005,   990,
     991,  1009,  -710,  1010,  1011,  -710,  1012,   633,   750,   783,
    -710,  -710,  -710,  1013,  -710,  -710,  1017,  1018,  1019,  1014,
    1021,  1022,  -710,  -710,  -710,  -710,  1023,   -27,   -27,   -27,
     -27,   -27,   586,  1020,   855,  -710,  1016,  1024,  1027,  -710,
    1025,  1026,  1029,  1028,  1030,  1032,  -710,  1033,   -12,   216,
    -710,   340,   340,   340,   340,   340,   340,   340,   340,   340,
     340,   340,   340,   340,   340,   340,   340,  1034,  1037,  1040,
    1039,  -710,  1044,  -710,  -710,  -710,   218,  -710,   340,  1045,
     220,  -710,   340,  -710,   340,   340,  -710,  1046,   838,  -710,
    -710,  -710,  -710,  -710,  -710,  1043,  1047,  1048,     9,  1051,
    1052,  1053,  1054,  1055,  1056,  1057,  1058,  1059,  1060,  1061,
    1062,  1066,  -710,  -710,   340,   340,  1049,  -710,   340,   340,
    -710,   340,   340,   340,   657,  1038,  1068,  -710,   340,   222,
    -710,  -710,   224,   226,   228,   240,   241,   252,   254,   258,
     259,   260,   264,   274,   275,   276,   280,  -710,  -710,  1065,
    -710,  1067,  -710,  1070,   301,   302,  -710,   -33,   -11,   300,
    -710,   307,  1050,  1069,  1071,  -710,  -710,  1072,  1073,  1074,
    1075,  1077,  1079,  -710,  -710,  -710,  -710,  -710,  -710,  1076,
     308,   309,  -710,  1078,   313,  1080,   314,   315,  1068,  1068,
    -710,   -71,  -710,  -710,   340,  -710,  -710,  -710,  -710,  -710,
    -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,  -710,
    -710,  -710,  1081,  -710,  -710,   340,  1083,  1084,   340,  -710,
      13,  1087,     3,   802,  1015,  1082,  1088,  1085,  1086,  1089,
    -710,  -710,  -710,  -710,  1090,  -710,  -710,  1091,  -710,   -63,
     -61,  1094,   340,  -124,  -710,  1096,   319,  1093,  1097,   -10,
     371,  1041,  1042,  1095,  1098,  1099,  1100,  1101,  1103,  1105,
    1106,  1102,  1107,  1108,  1109,  1110,  1112,   340,  -122,   340,
    -103,  -710,  -710,   340,  1092,  1111,  -710,  -710,  -710,  1117,
    -710,  -710,  -710,  1104,  1113,  1120,  1114,  1122,  -710,  -710,
    -710,  1119,  -710,  -710,  1124,  -710,  1109,  -710,  -710,  -710,
    -710,   340,  1115,  -710,   340,  1116,  -710,   340,  1123,  1125,
    1121,  1063,  1118,  1130,  1126,  -710,   834,  -710,  -710,   340,
    -710,   340,  -710,  1127,  -710,  1132,  -710,  -710,  1128,  -710,
    1133,  -710,  -710,  -710,  1129,  -710,  1131,  -710,  -710
};

/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
   Performed when YYTABLE does not specify something else to do.  Zero
   means the default is an error.  */
static const yytype_int16 yydefact[] =
{
       4,     0,     0,     0,     0,     0,   205,     3,     5,     0,
       0,     0,     0,     0,     1,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   204,   183,   205,    17,
     182,     0,     6,     0,     7,     9,    10,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   203,
     203,   203,   203,   203,   203,   203,   203,   203,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,   203,     0,     0,
       0,   203,     0,   203,     0,   203,   203,   119,     0,     2,
      18,     0,     0,     0,     0,     0,     0,     0,   207,     8,
      11,    12,   241,   242,   243,   244,   245,     0,     0,     0,
       0,   130,   137,     0,     0,     0,     0,     0,     0,     0,
       0,   236,     0,   230,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,   202,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,   211,   212,     0,
     206,   209,   210,     0,     0,     0,     0,     0,   133,     0,
       0,     0,     0,     0,     0,     0,    49,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,    51,    52,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   116,
       0,   117,   172,     0,     0,     0,   169,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,    99,   100,   101,   102,   103,   104,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,   148,     0,     0,     0,   145,
       0,     0,     0,     0,    13,     0,     0,     0,     0,     0,
       0,     0,   118,     0,     0,     0,     0,     0,   138,   135,
     134,     0,     0,     0,     0,     0,   231,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,   257,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,    86,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   214,   214,   214,     0,
     214,   214,     0,     0,   208,     0,   132,   173,     0,     0,
     136,   176,     0,     0,     0,    54,    55,    56,    57,    58,
      59,    60,    61,    65,    66,    67,    68,    62,    63,    64,
      35,   258,     0,     0,     0,     0,     0,     0,     0,     0,
      34,    33,    50,    53,   180,    69,    71,    72,    73,    83,
      84,    74,    70,    75,    76,    77,    78,    79,    80,    81,
      82,     0,     0,     0,   259,     0,    85,     0,     0,     0,
       0,     0,     0,     0,     0,   198,     0,     0,     0,     0,
     114,   106,     0,     0,   171,     0,    88,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     170,     0,    41,     0,     0,     0,   111,   112,   113,     0,
       0,     0,     0,    23,     0,     0,     0,   146,   147,     0,
       0,     0,     0,     0,     0,    14,     0,     0,     0,     0,
     214,     0,     0,   121,   120,   131,     0,     0,     0,     0,
       0,    32,     0,     0,     0,     0,    31,    28,     0,    30,
     185,     0,     0,     0,    87,     0,     0,     0,     0,     0,
       0,   200,   201,   194,     0,   195,   196,   197,   115,    19,
       0,    98,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,   236,     0,   236,     0,     0,   255,     0,     0,     0,
       0,     0,   144,     0,     0,    15,     0,     0,     0,     0,
     219,   217,   220,   213,   215,   221,     0,     0,     0,     0,
       0,     0,   174,   175,   177,   178,     0,     0,     0,     0,
       0,     0,     0,     0,   184,   187,     0,     0,     0,   260,
       0,     0,     0,     0,     0,     0,   199,     0,     0,     0,
     239,   238,   238,   238,   238,   238,   238,   238,   238,   238,
     238,   238,   238,   238,   238,   238,   238,     0,     0,     0,
       0,    42,     0,    44,    45,   105,     0,   109,     0,     0,
       0,    36,     0,    38,     0,     0,    22,     0,     0,   139,
     140,   141,   142,   143,    16,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,   181,   186,     0,     0,     0,    90,     0,     0,
      91,     0,     0,     0,     0,     0,     0,    89,     0,     0,
     237,   234,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,   165,   166,     0,
     168,     0,   128,     0,     0,     0,    48,     0,     0,     0,
     256,     0,     0,     0,     0,   218,   216,     0,     0,     0,
       0,     0,     0,   179,    24,    25,    26,    27,    29,     0,
       0,     0,   261,     0,     0,     0,     0,     0,     0,     0,
     232,     0,   240,   158,   238,   149,   159,   150,   164,   157,
     161,   152,   160,   151,   162,   153,   156,   154,   163,   155,
     167,    43,     0,   107,   110,     0,     0,     0,     0,    21,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
      46,    47,    92,    94,     0,    93,    95,     0,    20,     0,
       0,     0,     0,     0,   235,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,   190,     0,     0,     0,     0,     0,
       0,   233,   246,     0,     0,     0,   108,    37,    39,     0,
     222,   223,   224,     0,     0,     0,     0,     0,   122,   123,
     124,     0,   126,   127,     0,   188,   189,   192,    96,    97,
     249,     0,     0,   252,     0,     0,   247,     0,     0,     0,
       0,     0,     0,     0,     0,   125,     0,   191,   250,     0,
     253,     0,   248,     0,    40,     0,   225,   227,     0,   228,
       0,   251,   254,   129,     0,   226,     0,   229,   193
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
    -710,  -710,  -710,  -710,   714,  -710,  -710,  -710,  -710,   609,
    -710,  -710,  -710,  -710,  -343,  -710,  -710,  -595,  -710,  -435,
    -252,    17,  -710,  -710,  -710,   239,  -604,  -710,  -395,  -593,
     -59,  -557,  -709,  -136,  -311,  -710,  -710,  -172,  -115,  -137,
    -710
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
       0,     5,     6,     7,     8,   169,   625,   765,    28,    29,
     812,   790,   883,   884,   885,  1145,  1146,  1147,    30,   704,
     705,   275,    31,   339,   340,   341,   767,   863,   864,   865,
     202,  1041,   979,   203,   981,   899,   187,   900,   847,   525,
     407
};

/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule whose
   number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_int16 yytable[] =
{
     298,   299,   300,   301,   302,   303,   857,   858,   857,   858,
     262,     9,   857,   858,   201,   273,   857,   858,   229,   230,
     276,   278,   405,   768,   769,    15,   771,   772,   274,    14,
     201,   280,   201,   274,   274,    16,    17,    18,    19,  1123,
      10,  1151,   342,    15,   274,    20,    21,    22,    23,    24,
      25,   201,   265,    16,    17,    18,    19,   693,    12,    13,
    1154,   694,   282,    20,    21,    22,    23,    24,    25,   171,
     172,   173,   174,   175,   176,   274,   284,   168,   288,   888,
     177,    33,    35,   889,    34,    26,   178,    45,  1091,   274,
      27,   274,  1092,    46,    36,   859,  1091,   859,  1091,  1093,
    1117,   859,  1119,    26,    11,   859,   194,  1118,    27,  1120,
     263,   264,   195,   337,   338,   201,   408,   409,   410,   411,
     412,   413,   522,   350,   523,   522,   357,    37,   524,   351,
    1066,   524,   706,   707,   708,   427,   428,   277,   279,   281,
     283,   285,   286,   287,   289,   974,   975,    40,   357,   357,
     976,   192,  1067,  1129,   193,  1104,    38,  1105,   860,   861,
     862,  1106,   860,  1015,   862,  1100,   869,  1101,   182,   183,
     184,   185,   186,   533,   319,   534,   356,    39,   323,   357,
     325,    41,   327,   328,     1,     2,     3,     4,   383,   573,
     574,   357,   406,   982,   983,   984,   985,   986,   987,   988,
     989,   990,   991,   992,   993,   994,   995,   996,   384,   421,
     557,   357,   357,   558,   645,   646,   647,   357,   357,   357,
     648,   506,   649,   357,   650,   357,   651,   357,   652,   357,
     653,   357,   654,   357,   635,   357,   636,   526,   527,   528,
     529,   530,   531,   532,   655,   656,   657,   357,   357,   357,
     658,   659,   672,   357,   357,   357,   673,   675,   676,   357,
     357,   357,   677,   678,   679,   357,   357,   357,    50,   680,
     681,   559,   357,   357,   682,   683,   684,   357,   357,   357,
     685,   686,   687,   357,   357,   357,   688,   572,   689,   357,
     690,   357,   577,   357,   710,   742,    42,   357,   357,   507,
     508,   509,   510,   511,   512,   513,   514,   515,   516,   517,
     518,   519,   520,   521,   746,   747,   748,   357,   357,   357,
     179,   753,   781,   535,   357,   782,   536,    43,   538,   539,
     540,   541,   542,   543,   544,   545,   546,   547,   548,   549,
     550,   551,   552,   553,   622,   801,   803,   805,   802,   804,
     804,   806,   807,   808,   804,   804,   357,   342,    44,   809,
     918,   571,   357,   919,   927,    47,   357,   928,   357,   932,
     936,   934,   977,   937,  1002,   978,  1006,  1003,  1043,   357,
    1045,  1044,  1046,  1044,  1047,  1044,    48,  1044,   662,   663,
     664,   665,   666,   667,   668,   669,  1048,  1049,    49,  1044,
    1044,   603,   695,   180,   201,   607,   608,   609,  1050,   181,
    1051,  1044,   614,  1044,  1052,  1053,  1054,  1044,  1044,  1044,
    1055,   188,   506,  1044,   697,   698,   699,   700,   701,   702,
    1056,  1057,  1058,  1044,  1044,  1044,  1059,   632,   633,  1044,
     715,   717,   718,   719,   720,   721,   722,   723,   724,   725,
     726,   727,   728,   729,   730,   731,   732,  1063,  1064,   357,
     357,  1065,  1068,  1069,  1080,  1081,   937,   357,   357,  1083,
    1086,  1088,  1084,  1087,   357,  1126,   189,  1102,   357,  1107,
     756,  1089,  1090,   759,   190,   761,   762,   763,   191,   196,
     197,   200,   198,   199,   201,   204,   205,   206,   207,   208,
     209,   210,   211,   212,   213,   214,   215,   216,   217,   218,
     228,   709,   219,   220,   712,   221,   222,   223,   224,   225,
     226,   231,   227,   232,   233,   234,   235,   236,   237,   238,
     239,   240,   241,   242,   243,   244,   245,   246,   247,   248,
    1130,   963,   251,   252,   253,   254,   255,   256,   249,   250,
     257,  1167,   896,  1016,   267,   266,   271,   268,   258,   259,
     269,   260,   261,   270,   272,   293,   290,   291,   292,   358,
     294,   295,   274,   296,   297,   304,   305,   307,   306,   308,
     813,   814,   815,   816,   817,   818,   819,   820,   821,   822,
     823,   824,   825,   826,   827,   828,   309,   310,   311,   312,
     359,   360,   313,   314,   315,   836,   316,   317,   318,   320,
     321,   322,   324,   326,   329,   330,   331,   332,   333,   849,
     334,   335,   850,   336,   343,   853,   854,   344,   345,   346,
     347,   349,   352,   348,   353,   354,   355,   170,   403,   404,
     414,   361,   362,   418,   363,   877,   878,   879,   880,   364,
     365,   881,   366,   367,   368,   369,   370,   371,   372,   890,
     891,   892,   893,   894,   895,   373,   374,   375,   376,   377,
     378,   379,   380,   381,   382,   385,   898,   386,   387,   388,
     389,   390,   391,   392,   393,   394,   395,   396,   397,   398,
     399,   842,   844,   400,   401,   402,   415,   416,   417,   419,
     420,   423,   424,   422,   429,   426,   430,   425,   431,   495,
     432,   433,   496,   434,   435,   497,   436,   437,   502,   438,
     439,    32,   440,   441,   442,   443,   448,   444,   445,   446,
     447,   449,   634,  1094,   450,   462,   463,   453,   451,   452,
     956,   957,   958,   959,   960,   454,   455,   456,   457,   458,
     566,   567,   961,   459,   460,   461,   464,   465,   466,   467,
     468,   469,   470,   471,   472,   980,   980,   980,   980,   980,
     980,   980,   980,   980,   980,   980,   980,   980,   980,   980,
     980,   930,   473,   474,   475,   476,   477,   478,   479,   480,
     481,   482,   483,   484,   485,   486,   487,   488,   489,   490,
     491,   945,   674,   568,   494,   492,  1042,   503,   498,   493,
     499,   500,   501,   504,   537,   505,   554,   555,   556,  1038,
     560,   569,   561,  1011,   594,   595,   562,   563,   564,   565,
     570,   575,  1033,  1034,   576,  1035,  1036,   578,   579,   580,
     581,   582,   898,   583,   584,   585,   586,   587,   588,   589,
     590,   591,   592,   593,   596,   597,   598,   617,   620,   599,
     600,   601,   602,   644,   604,   605,   606,   610,   611,  1004,
     612,   613,   615,  1007,   616,  1008,  1009,   618,   619,   661,
     621,   626,   623,   624,   627,   628,   629,   630,   631,   638,
       0,     0,   637,   866,   640,   641,   639,   703,   660,   642,
     643,   670,   671,   691,   692,  1030,  1031,   713,   980,   696,
     711,   733,   714,   734,  1037,   735,   716,   736,   946,   737,
     743,   738,   740,   739,   741,   749,     0,   744,   745,   750,
     751,   752,   757,   754,   755,   758,   760,   766,   764,   770,
     780,   783,   773,   838,   774,   775,   776,   777,   778,   779,
     784,   947,   791,   786,   787,   785,  1122,  1124,   788,   789,
     792,   793,   794,   795,   796,   810,   797,  1108,     0,   798,
     799,   800,   811,   829,   830,   832,   831,   833,   834,   835,
     837,  1150,  1152,  1153,  1155,   839,   841,  1156,   840,   843,
     845,   846,   848,   851,   867,   852,   856,   868,   855,   876,
    1180,   870,   872,   873,   874,   875,  1096,   882,   871,  1099,
     920,   886,   887,   897,   926,  1168,   901,   902,  1170,   903,
     904,  1172,   905,   906,   907,   908,   909,   910,   911,   912,
     913,   914,   915,  1181,   916,  1182,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,    68,    69,    70,    71,    72,    73,    74,
      75,    76,    77,    78,    79,    80,    81,    82,    83,    84,
      85,    86,    87,    88,    89,    90,    91,    92,    93,    94,
      95,    96,    97,    98,   917,    99,   100,   101,   102,   103,
     104,   105,   106,   107,   108,   109,   110,   111,   112,   113,
     114,   115,   116,   117,   118,   119,   120,   121,   122,   123,
     124,   125,   126,   127,   128,   129,   130,   131,   132,   133,
     134,   135,   921,   922,   136,   137,   138,   139,   140,   141,
     142,   143,   923,   924,   925,   144,   145,   146,   147,   148,
     149,   150,   929,   931,   933,   935,   939,   940,   151,   152,
     153,   154,   155,   156,   157,   158,   159,   160,   161,   162,
     163,   164,   165,   166,   938,   941,   942,   943,   944,   949,
     950,   951,   948,   953,   954,   964,   962,   955,   952,   966,
    1109,   967,     0,   965,   970,   968,     0,   167,   969,   971,
     997,   972,   973,   998,   999,  1000,  1001,  1012,  1005,  1010,
    1039,  1013,  1014,  1017,  1018,  1019,  1020,  1021,  1022,  1070,
    1131,  1132,  1032,  1023,  1024,  1025,  1026,  1027,  1028,  1029,
    1040,  1060,  1062,  1061,  1073,  1074,  1075,  1076,  1071,  1077,
    1072,  1078,  1176,  1095,  1082,  1079,  1085,  1097,  1098,  1103,
    1111,     0,  1114,     0,  1115,  1116,  1121,  1110,  1125,  1127,
    1112,  1113,  1136,  1128,  1133,  1157,  1160,  1134,  1135,  1138,
    1137,  1139,  1140,  1142,  1143,  1161,  1148,  1141,  1149,  1144,
    1158,  1159,  1162,  1163,  1164,  1165,  1166,  1173,  1169,  1171,
    1175,  1174,  1178,  1183,  1184,  1186,     0,  1177,     0,     0,
       0,     0,  1188,     0,     0,  1179,     0,  1185,  1187
};

static const yytype_int16 yycheck[] =
{
     136,   137,   138,   139,   140,   141,     3,     4,     3,     4,
      53,   153,     3,     4,   154,   154,     3,     4,    77,    78,
     154,   154,   162,   627,   628,    91,   630,   631,   167,     0,
     154,   154,   154,   167,   167,   101,   102,   103,   104,   163,
     153,   163,   178,    91,   167,   111,   112,   113,   114,   115,
     116,   154,   111,   101,   102,   103,   104,   159,   157,   158,
     163,   163,   154,   111,   112,   113,   114,   115,   116,   133,
     134,   135,   136,   137,   138,   167,   154,   143,   154,   159,
     144,   153,   156,   163,   156,   151,   150,   152,   159,   167,
     156,   167,   163,   158,   156,    92,   159,    92,   159,   170,
     163,    92,   163,   151,   153,    92,   152,   170,   156,   170,
     153,   154,   158,   152,   153,   154,   252,   253,   254,   255,
     256,   257,   152,   152,   154,   152,   159,   152,   158,   158,
     163,   158,   567,   568,   569,   271,   272,   120,   121,   122,
     123,   124,   125,   126,   127,   157,   158,   154,   159,   159,
     162,   156,   163,   163,   159,   152,   152,   154,   153,   154,
     155,   158,   153,   154,   155,   152,   770,   154,   145,   146,
     147,   148,   149,   152,   157,   154,   156,   152,   161,   159,
     163,   154,   165,   166,   139,   140,   141,   142,   156,   159,
     160,   159,   251,   902,   903,   904,   905,   906,   907,   908,
     909,   910,   911,   912,   913,   914,   915,   916,   156,   156,
     156,   159,   159,   159,   156,   156,   156,   159,   159,   159,
     156,   357,   156,   159,   156,   159,   156,   159,   156,   159,
     156,   159,   156,   159,   154,   159,   156,   374,   375,   376,
     377,   378,   379,   380,   156,   156,   156,   159,   159,   159,
     156,   156,   156,   159,   159,   159,   156,   156,   156,   159,
     159,   159,   156,   156,   156,   159,   159,   159,   152,   156,
     156,   407,   159,   159,   156,   156,   156,   159,   159,   159,
     156,   156,   156,   159,   159,   159,   156,   423,   156,   159,
     156,   159,   428,   159,   156,   156,   154,   159,   159,   358,
     359,   360,   361,   362,   363,   364,   365,   366,   367,   368,
     369,   370,   371,   372,   156,   156,   156,   159,   159,   159,
     156,   156,   156,   382,   159,   159,   385,   154,   387,   388,
     389,   390,   391,   392,   393,   394,   395,   396,   397,   398,
     399,   400,   401,   402,   481,   152,   156,   156,   155,   159,
     159,   156,   156,   156,   159,   159,   159,   493,   154,   156,
     154,   420,   159,   157,   156,   154,   159,   159,   159,   162,
     156,   162,   156,   159,   156,   159,   156,   159,   156,   159,
     156,   159,   156,   159,   156,   159,   154,   159,   525,   526,
     527,   528,   529,   530,   531,   532,   156,   156,   154,   159,
     159,   460,   152,   156,   154,   464,   465,   466,   156,   156,
     156,   159,   471,   159,   156,   156,   156,   159,   159,   159,
     156,   159,   558,   159,   560,   561,   562,   563,   564,   565,
     156,   156,   156,   159,   159,   159,   156,   152,   153,   159,
     576,   578,   579,   580,   581,   582,   583,   584,   585,   586,
     587,   588,   589,   590,   591,   592,   593,   156,   156,   159,
     159,   159,   162,   156,   156,   156,   159,   159,   159,   156,
     156,   156,   159,   159,   159,   156,   159,  1070,   159,  1072,
     617,  1038,  1039,   620,   159,   622,   623,   624,   156,   152,
     159,   152,   159,   159,   154,   152,   152,   152,   152,   152,
     152,   152,   152,   152,   152,   152,   152,   152,   152,   152,
     152,   570,   153,   153,   573,   153,   153,   153,   153,   153,
     153,   152,   154,   153,   152,   152,   152,   152,   152,   152,
     152,   152,   152,   152,   152,   152,   152,   152,   152,   152,
     169,   884,   152,   152,   152,   152,   152,   152,   160,   160,
     152,  1146,   804,   948,   152,   154,   152,   154,   162,   162,
     154,   162,   162,   154,   152,   154,   153,   153,   153,   159,
     154,   154,   167,   154,   154,   152,   154,   152,   154,   152,
     717,   718,   719,   720,   721,   722,   723,   724,   725,   726,
     727,   728,   729,   730,   731,   732,   152,   152,   152,   152,
     159,   159,   154,   154,   154,   741,   154,   153,   153,   153,
     153,   153,   153,   153,   152,   152,   152,   152,   152,   756,
     152,   152,   759,   152,   152,   762,   763,   154,   154,   154,
     154,   152,   154,   156,   154,   154,   152,    28,   152,   152,
     152,   159,   159,   154,   159,   782,   783,   784,   785,   159,
     159,   788,   159,   159,   159,   159,   159,   159,   159,   795,
     796,   797,   798,   799,   800,   159,   159,   159,   159,   159,
     159,   159,   159,   159,   159,   159,   812,   160,   159,   159,
     159,   159,   159,   159,   159,   159,   159,   159,   159,   159,
     159,   750,   751,   159,   159,   159,   152,   152,   152,   156,
     159,   159,   152,   156,   152,   156,   153,   159,   152,   154,
     153,   152,   154,   153,   152,   154,   153,   152,   154,   153,
     152,     7,   153,   153,   153,   152,   159,   153,   152,   152,
     152,   159,   493,  1044,   159,   152,   152,   156,   159,   159,
     877,   878,   879,   880,   881,   156,   156,   156,   156,   156,
     163,   163,   166,   159,   159,   159,   159,   159,   159,   159,
     159,   159,   159,   159,   159,   901,   902,   903,   904,   905,
     906,   907,   908,   909,   910,   911,   912,   913,   914,   915,
     916,   840,   159,   153,   156,   159,   159,   153,   156,   153,
     159,   153,   153,   156,   152,   152,   152,   152,   152,   152,
     152,   168,   161,   163,   153,   156,   978,   154,   156,   159,
     156,   156,   152,   154,   152,   159,   152,   152,   152,   162,
     159,   163,   159,   938,   152,   152,   159,   159,   159,   159,
     159,   154,   968,   969,   159,   971,   972,   159,   159,   159,
     159,   159,   978,   159,   159,   159,   159,   159,   159,   159,
     159,   159,   159,   159,   152,   152,   152,   159,   159,   154,
     154,   154,   152,   154,   153,   153,   153,   152,   152,   928,
     152,   152,   152,   932,   152,   934,   935,   152,   152,   152,
     159,   153,   159,   159,   153,   153,   153,   153,   153,   159,
      -1,    -1,   156,   164,   156,   156,   159,   153,   156,   159,
     159,   156,   156,   152,   152,   964,   965,   152,  1044,   156,
     156,   152,   156,   152,   973,   152,   159,   159,   168,   159,
     153,   159,   156,   159,   159,   152,    -1,   159,   159,   159,
     159,   159,   156,   159,   159,   156,   152,   159,   153,   152,
     159,   159,   156,   153,   156,   156,   154,   154,   154,   154,
     159,   168,   152,   156,   156,   159,  1092,  1093,   159,   156,
     152,   152,   156,   159,   159,   152,   159,   165,    -1,   159,
     159,   159,   156,   159,   159,   152,   159,   152,   152,   152,
     152,  1117,  1118,  1119,  1120,   154,   154,  1123,   159,   154,
     154,   153,   152,   152,   164,   156,   153,   164,   156,   154,
     166,   164,   156,   156,   156,   156,  1065,   152,   164,  1068,
     154,   161,   161,   161,   152,  1151,   159,   159,  1154,   159,
     159,  1157,   159,   159,   159,   159,   159,   159,   159,   159,
     159,   159,   159,  1169,   159,  1171,     5,     6,     7,     8,
       9,    10,    11,    12,    13,    14,    15,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,    35,    36,    37,    38,
      39,    40,    41,    42,    43,    44,    45,    46,    47,    48,
      49,    50,    51,    52,   153,    54,    55,    56,    57,    58,
      59,    60,    61,    62,    63,    64,    65,    66,    67,    68,
      69,    70,    71,    72,    73,    74,    75,    76,    77,    78,
      79,    80,    81,    82,    83,    84,    85,    86,    87,    88,
      89,    90,   156,   159,    93,    94,    95,    96,    97,    98,
      99,   100,   156,   156,   156,   104,   105,   106,   107,   108,
     109,   110,   159,   156,   156,   159,   156,   156,   117,   118,
     119,   120,   121,   122,   123,   124,   125,   126,   127,   128,
     129,   130,   131,   132,   159,   156,   156,   156,   156,   152,
     152,   152,   159,   152,   152,   159,   156,   154,   164,   152,
     165,   156,    -1,   159,   156,   159,    -1,   156,   159,   159,
     156,   159,   159,   156,   154,   156,   152,   154,   153,   153,
     162,   154,   154,   152,   152,   152,   152,   152,   152,   159,
     169,   169,   163,   156,   156,   156,   156,   156,   156,   153,
     152,   156,   152,   156,   152,   152,   152,   152,   159,   152,
     159,   152,   169,   152,   156,   159,   156,   154,   154,   152,
     152,    -1,   153,    -1,   154,   154,   152,   165,   152,   156,
     165,   165,   152,   156,   159,   163,   152,   159,   159,   156,
     159,   156,   156,   156,   156,   152,   156,   165,   156,   160,
     159,   154,   152,   159,   152,   156,   152,   154,   163,   163,
     159,   156,   152,   156,   152,   152,    -1,   169,    -1,    -1,
      -1,    -1,   161,    -1,    -1,   169,    -1,   169,   169
};

/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
   state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,   139,   140,   141,   142,   172,   173,   174,   175,   153,
     153,   153,   157,   158,     0,    91,   101,   102,   103,   104,
     111,   112,   113,   114,   115,   116,   151,   156,   179,   180,
     189,   193,   175,   153,   156,   156,   156,   152,   152,   152,
     154,   154,   154,   154,   154,   152,   158,   154,   154,   154,
     152,     5,     6,     7,     8,     9,    10,    11,    12,    13,
      14,    15,    16,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    35,    36,    37,    38,    39,    40,    41,    42,    43,
      44,    45,    46,    47,    48,    49,    50,    51,    52,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,    68,    69,    70,    71,    72,    73,    74,
      75,    76,    77,    78,    79,    80,    81,    82,    83,    84,
      85,    86,    87,    88,    89,    90,    93,    94,    95,    96,
      97,    98,    99,   100,   104,   105,   106,   107,   108,   109,
     110,   117,   118,   119,   120,   121,   122,   123,   124,   125,
     126,   127,   128,   129,   130,   131,   132,   156,   143,   176,
     180,   133,   134,   135,   136,   137,   138,   144,   150,   156,
     156,   156,   145,   146,   147,   148,   149,   207,   159,   159,
     159,   156,   156,   159,   152,   158,   152,   159,   159,   159,
     152,   154,   201,   204,   152,   152,   152,   152,   152,   152,
     152,   152,   152,   152,   152,   152,   152,   152,   152,   153,
     153,   153,   153,   153,   153,   153,   153,   154,   152,   201,
     201,   152,   153,   152,   152,   152,   152,   152,   152,   152,
     152,   152,   152,   152,   152,   152,   152,   152,   152,   160,
     160,   152,   152,   152,   152,   152,   152,   152,   162,   162,
     162,   162,    53,   153,   154,   201,   154,   152,   154,   154,
     154,   152,   152,   154,   167,   192,   154,   192,   154,   192,
     154,   192,   154,   192,   154,   192,   192,   192,   154,   192,
     153,   153,   153,   154,   154,   154,   154,   154,   204,   204,
     204,   204,   204,   204,   152,   154,   154,   152,   152,   152,
     152,   152,   152,   154,   154,   154,   154,   153,   153,   192,
     153,   153,   153,   192,   153,   192,   153,   192,   192,   152,
     152,   152,   152,   152,   152,   152,   152,   152,   153,   194,
     195,   196,   204,   152,   154,   154,   154,   154,   156,   152,
     152,   158,   154,   154,   154,   152,   156,   159,   159,   159,
     159,   159,   159,   159,   159,   159,   159,   159,   159,   159,
     159,   159,   159,   159,   159,   159,   159,   159,   159,   159,
     159,   159,   159,   156,   156,   159,   160,   159,   159,   159,
     159,   159,   159,   159,   159,   159,   159,   159,   159,   159,
     159,   159,   159,   152,   152,   162,   201,   211,   204,   204,
     204,   204,   204,   204,   152,   152,   152,   152,   154,   156,
     159,   156,   156,   159,   152,   159,   156,   204,   204,   152,
     153,   152,   153,   152,   153,   152,   153,   152,   153,   152,
     153,   153,   153,   152,   153,   152,   152,   152,   159,   159,
     159,   159,   159,   156,   156,   156,   156,   156,   156,   159,
     159,   159,   152,   152,   159,   159,   159,   159,   159,   159,
     159,   159,   159,   159,   153,   156,   159,   159,   153,   156,
     153,   159,   153,   153,   156,   152,   152,   152,   152,   152,
     152,   152,   156,   159,   153,   154,   154,   154,   156,   156,
     156,   152,   154,   154,   154,   159,   204,   201,   201,   201,
     201,   201,   201,   201,   201,   201,   201,   201,   201,   201,
     201,   201,   152,   154,   158,   210,   210,   210,   210,   210,
     210,   210,   210,   152,   154,   201,   201,   152,   201,   201,
     201,   201,   201,   201,   201,   201,   201,   201,   201,   201,
     201,   201,   201,   201,   152,   152,   152,   156,   159,   204,
     159,   159,   159,   159,   159,   159,   163,   163,   163,   163,
     159,   201,   204,   159,   160,   154,   159,   204,   159,   159,
     159,   159,   159,   159,   159,   159,   159,   159,   159,   159,
     159,   159,   159,   159,   152,   152,   152,   152,   152,   154,
     154,   154,   152,   201,   153,   153,   153,   201,   201,   201,
     152,   152,   152,   152,   201,   152,   152,   159,   152,   152,
     159,   159,   210,   159,   159,   177,   153,   153,   153,   153,
     153,   153,   152,   153,   196,   154,   156,   156,   159,   159,
     156,   156,   159,   159,   154,   156,   156,   156,   156,   156,
     156,   156,   156,   156,   156,   156,   156,   156,   156,   156,
     156,   152,   210,   210,   210,   210,   210,   210,   210,   210,
     156,   156,   156,   156,   161,   156,   156,   156,   156,   156,
     156,   156,   156,   156,   156,   156,   156,   156,   156,   156,
     156,   152,   152,   159,   163,   152,   156,   204,   204,   204,
     204,   204,   204,   153,   190,   191,   190,   190,   190,   201,
     156,   156,   201,   152,   156,   204,   159,   210,   210,   210,
     210,   210,   210,   210,   210,   210,   210,   210,   210,   210,
     210,   210,   210,   152,   152,   152,   159,   159,   159,   159,
     156,   159,   156,   153,   159,   159,   156,   156,   156,   152,
     159,   159,   159,   156,   159,   159,   210,   156,   156,   210,
     152,   210,   210,   210,   153,   178,   159,   197,   197,   197,
     152,   197,   197,   156,   156,   156,   154,   154,   154,   154,
     159,   156,   159,   159,   159,   159,   156,   156,   159,   156,
     182,   152,   152,   152,   156,   159,   159,   159,   159,   159,
     159,   152,   155,   156,   159,   156,   156,   156,   156,   156,
     152,   156,   181,   210,   210,   210,   210,   210,   210,   210,
     210,   210,   210,   210,   210,   210,   210,   210,   210,   159,
     159,   159,   152,   152,   152,   152,   204,   152,   153,   154,
     159,   154,   201,   154,   201,   154,   153,   209,   152,   210,
     210,   152,   156,   210,   210,   156,   153,     3,     4,    92,
     153,   154,   155,   198,   199,   200,   164,   164,   164,   197,
     164,   164,   156,   156,   156,   156,   154,   210,   210,   210,
     210,   210,   152,   183,   184,   185,   161,   161,   159,   163,
     204,   204,   204,   204,   204,   204,   191,   161,   204,   206,
     208,   159,   159,   159,   159,   159,   159,   159,   159,   159,
     159,   159,   159,   159,   159,   159,   159,   153,   154,   157,
     154,   156,   159,   156,   156,   156,   152,   156,   159,   159,
     201,   156,   162,   156,   162,   159,   156,   159,   159,   156,
     156,   156,   156,   156,   156,   168,   168,   168,   159,   152,
     152,   152,   164,   152,   152,   154,   210,   210,   210,   210,
     210,   166,   156,   185,   159,   159,   152,   156,   159,   159,
     156,   159,   159,   159,   157,   158,   162,   156,   159,   203,
     204,   205,   203,   203,   203,   203,   203,   203,   203,   203,
     203,   203,   203,   203,   203,   203,   203,   156,   156,   154,
     156,   152,   156,   159,   201,   153,   156,   201,   201,   201,
     153,   209,   154,   154,   154,   154,   199,   152,   152,   152,
     152,   152,   152,   156,   156,   156,   156,   156,   156,   153,
     201,   201,   163,   204,   204,   204,   204,   201,   162,   162,
     152,   202,   208,   156,   159,   156,   156,   156,   156,   156,
     156,   156,   156,   156,   156,   156,   156,   156,   156,   156,
     156,   156,   152,   156,   156,   159,   163,   163,   162,   156,
     159,   159,   159,   152,   152,   152,   152,   152,   152,   159,
     156,   156,   156,   156,   159,   156,   156,   159,   156,   202,
     202,   159,   163,   170,   205,   152,   201,   154,   154,   201,
     152,   154,   200,   152,   152,   154,   158,   200,   165,   165,
     165,   152,   165,   165,   153,   154,   154,   163,   170,   163,
     170,   152,   204,   163,   204,   152,   156,   156,   156,   163,
     169,   169,   169,   159,   159,   159,   152,   159,   156,   156,
     156,   165,   156,   156,   160,   186,   187,   188,   156,   156,
     204,   163,   204,   204,   163,   204,   204,   163,   159,   154,
     152,   152,   152,   159,   152,   156,   152,   188,   204,   163,
     204,   163,   204,   154,   156,   159,   169,   169,   152,   169,
     166,   204,   204,   156,   152,   169,   152,   169,   161
};

/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
static const yytype_uint8 yyr1[] =
{
       0,   171,   172,   173,   173,   174,   174,   175,   175,   175,
     175,   175,   175,   177,   176,   178,   178,   179,   179,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   181,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
     182,   180,   180,   180,   183,   183,   184,   184,   185,   186,
     186,   187,   187,   188,   189,   189,   189,   189,   190,   190,
     191,   191,   192,   192,   193,   193,   194,   194,   195,   195,
     196,   196,   196,   197,   197,   198,   198,   198,   198,   199,
     199,   199,   200,   200,   200,   200,   200,   200,   200,   200,
     201,   201,   202,   202,   203,   203,   204,   205,   205,   206,
     206,   207,   207,   207,   207,   207,   208,   208,   208,   208,
     208,   208,   208,   208,   208,   209,   209,   210,   210,   211,
     211,   211
};

/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
static const yytype_int8 yyr2[] =
{
       0,     2,     3,     1,     0,     1,     2,     3,     4,     3,
       3,     4,     4,     0,     5,     2,     3,     1,     2,     7,
      11,    10,     8,     6,    10,    10,    10,    10,     7,    10,
       7,     7,     7,     6,     6,     6,     8,    12,     8,    12,
      14,     6,     8,    10,     8,     8,    11,    11,     9,     4,
       6,     4,     4,     6,     6,     6,     6,     6,     6,     6,
       6,     6,     6,     6,     6,     6,     6,     6,     6,     6,
       6,     6,     6,     6,     6,     6,     6,     6,     6,     6,
       6,     6,     6,     6,     6,     6,     5,     7,     0,     9,
       9,     9,    11,    11,    11,    11,    13,    13,     7,     4,
       4,     4,     4,     4,     4,     8,     6,    10,    12,     8,
      10,     6,     6,     6,     6,     7,     4,     4,     4,     2,
       6,     6,    12,    12,    12,    13,    12,    12,     9,    15,
       3,     7,     6,     4,     5,     5,     6,     3,     5,     8,
       8,     8,     8,     8,     7,     4,     6,     6,     4,    10,
      10,    10,    10,    10,    10,    10,    10,    10,    10,    10,
      10,    10,    10,    10,    10,     9,     9,    10,     9,     4,
       6,     6,     4,     6,     8,     8,     6,     8,     8,    10,
       0,     9,     1,     1,     1,     0,     2,     1,     6,     1,
       0,     2,     1,     5,     7,     7,     7,     7,     1,     3,
       2,     2,     1,     0,     1,     0,     1,     0,     3,     1,
       1,     1,     1,     2,     0,     1,     3,     1,     3,     1,
       1,     1,     6,     6,     6,     8,     9,     8,     8,    10,
       1,     3,     1,     3,     1,     3,     1,     1,     0,     1,
       3,     1,     1,     1,     1,     1,     5,     6,     7,     6,
       7,     8,     6,     7,     8,     1,     3,     1,     2,     3,
       5,     7
};


enum { YYENOMEM = -2 };

#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = YYEMPTY)

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab
#define YYNOMEM         goto yyexhaustedlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                    \
  do                                                              \
    if (yychar == YYEMPTY)                                        \
      {                                                           \
        yychar = (Token);                                         \
        yylval = (Value);                                         \
        YYPOPSTACK (yylen);                                       \
        yystate = *yyssp;                                         \
        goto yybackup;                                            \
      }                                                           \
    else                                                          \
      {                                                           \
        yyerror (YY_("syntax error: cannot back up")); \
        YYERROR;                                                  \
      }                                                           \
  while (0)

/* Backward compatibility with an undocumented macro.
   Use YYerror or YYUNDEF. */
#define YYERRCODE YYUNDEF


/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)




# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Kind, Value); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*-----------------------------------.
| Print this symbol's value on YYO.  |
`-----------------------------------*/

static void
yy_symbol_value_print (FILE *yyo,
                       yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
{
  FILE *yyoutput = yyo;
  YY_USE (yyoutput);
  if (!yyvaluep)
    return;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/*---------------------------.
| Print this symbol on YYO.  |
`---------------------------*/

static void
yy_symbol_print (FILE *yyo,
                 yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
{
  YYFPRINTF (yyo, "%s %s (",
             yykind < YYNTOKENS ? "token" : "nterm", yysymbol_name (yykind));

  yy_symbol_value_print (yyo, yykind, yyvaluep);
  YYFPRINTF (yyo, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yy_state_t *yybottom, yy_state_t *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yy_state_t *yyssp, YYSTYPE *yyvsp,
                 int yyrule)
{
  int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %d):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       YY_ACCESSING_SYMBOL (+yyssp[yyi + 1 - yynrhs]),
                       &yyvsp[(yyi + 1) - (yynrhs)]);
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args) ((void) 0)
# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif






/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg,
            yysymbol_kind_t yykind, YYSTYPE *yyvaluep)
{
  YY_USE (yyvaluep);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/* Lookahead token kind.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;
/* Number of syntax errors so far.  */
int yynerrs;




/*----------.
| yyparse.  |
`----------*/

int
yyparse (void)
{
    yy_state_fast_t yystate = 0;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus = 0;

    /* Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* Their size.  */
    YYPTRDIFF_T yystacksize = YYINITDEPTH;

    /* The state stack: array, bottom, top.  */
    yy_state_t yyssa[YYINITDEPTH];
    yy_state_t *yyss = yyssa;
    yy_state_t *yyssp = yyss;

    /* The semantic value stack: array, bottom, top.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs = yyvsa;
    YYSTYPE *yyvsp = yyvs;

  int yyn;
  /* The return value of yyparse.  */
  int yyresult;
  /* Lookahead symbol kind.  */
  yysymbol_kind_t yytoken = YYSYMBOL_YYEMPTY;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;



#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yychar = YYEMPTY; /* Cause a token to be read.  */

  goto yysetstate;


/*------------------------------------------------------------.
| yynewstate -- push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;


/*--------------------------------------------------------------------.
| yysetstate -- set current state (the top of the stack) to yystate.  |
`--------------------------------------------------------------------*/
yysetstate:
  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
  YY_IGNORE_USELESS_CAST_BEGIN
  *yyssp = YY_CAST (yy_state_t, yystate);
  YY_IGNORE_USELESS_CAST_END
  YY_STACK_PRINT (yyss, yyssp);

  if (yyss + yystacksize - 1 <= yyssp)
#if !defined yyoverflow && !defined YYSTACK_RELOCATE
    YYNOMEM;
#else
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYPTRDIFF_T yysize = yyssp - yyss + 1;

# if defined yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        yy_state_t *yyss1 = yyss;
        YYSTYPE *yyvs1 = yyvs;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * YYSIZEOF (*yyssp),
                    &yyvs1, yysize * YYSIZEOF (*yyvsp),
                    &yystacksize);
        yyss = yyss1;
        yyvs = yyvs1;
      }
# else /* defined YYSTACK_RELOCATE */
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        YYNOMEM;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yy_state_t *yyss1 = yyss;
        union yyalloc *yyptr =
          YY_CAST (union yyalloc *,
                   YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
        if (! yyptr)
          YYNOMEM;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YY_IGNORE_USELESS_CAST_BEGIN
      YYDPRINTF ((stderr, "Stack size increased to %ld\n",
                  YY_CAST (long, yystacksize)));
      YY_IGNORE_USELESS_CAST_END

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }
#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */


  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;


/*-----------.
| yybackup.  |
`-----------*/
yybackup:
  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token\n"));
      yychar = yylex ();
    }

  if (yychar <= YYEOF)
    {
      yychar = YYEOF;
      yytoken = YYSYMBOL_YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else if (yychar == YYerror)
    {
      /* The scanner already issued an error message, process directly
         to error recovery.  But do not keep the error token as
         lookahead, it is too special and may lead us to an endless
         loop in error recovery. */
      yychar = YYUNDEF;
      yytoken = YYSYMBOL_YYerror;
      goto yyerrlab1;
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  /* Discard the shifted token.  */
  yychar = YYEMPTY;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
  case 7: /* header_line: K_ivl_version T_STRING ';'  */
#line 151 "parse.y"
                { verify_version((yyvsp[-1].text), NULL); }
#line 2060 "parse.cc"
    break;

  case 8: /* header_line: K_ivl_version T_STRING T_STRING ';'  */
#line 153 "parse.y"
                { verify_version((yyvsp[-2].text), (yyvsp[-1].text)); }
#line 2066 "parse.cc"
    break;

  case 9: /* header_line: K_ivl_delay_selection T_STRING ';'  */
#line 155 "parse.y"
                { set_delay_selection((yyvsp[-1].text)); }
#line 2072 "parse.cc"
    break;

  case 10: /* header_line: K_vpi_module T_STRING ';'  */
#line 157 "parse.y"
                { compile_load_vpi_module((yyvsp[-1].text)); }
#line 2078 "parse.cc"
    break;

  case 11: /* header_line: K_vpi_time_precision '+' T_NUMBER ';'  */
#line 159 "parse.y"
                { compile_vpi_time_precision((yyvsp[-1].numb)); }
#line 2084 "parse.cc"
    break;

  case 12: /* header_line: K_vpi_time_precision '-' T_NUMBER ';'  */
#line 161 "parse.y"
                { compile_vpi_time_precision(-(yyvsp[-1].numb)); }
#line 2090 "parse.cc"
    break;

  case 13: /* $@1: %empty  */
#line 165 "parse.y"
                                    { file_names.reserve((yyvsp[-1].numb)); }
#line 2096 "parse.cc"
    break;

  case 15: /* name_strings: T_STRING ';'  */
#line 171 "parse.y"
                { file_names.push_back((yyvsp[-1].text)); }
#line 2102 "parse.cc"
    break;

  case 16: /* name_strings: name_strings T_STRING ';'  */
#line 173 "parse.y"
                { file_names.push_back((yyvsp[-1].text)); }
#line 2108 "parse.cc"
    break;

  case 19: /* statement: T_LABEL K_FUNCTOR T_SYMBOL T_NUMBER ',' symbols ';'  */
#line 195 "parse.y"
                { compile_functor((yyvsp[-6].text), (yyvsp[-4].text), (yyvsp[-3].numb), 6, 6, (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 2114 "parse.cc"
    break;

  case 20: /* statement: T_LABEL K_FUNCTOR T_SYMBOL T_NUMBER '[' T_NUMBER T_NUMBER ']' ',' symbols ';'  */
#line 199 "parse.y"
                { unsigned str0 = (yyvsp[-5].numb);
		  unsigned str1 = (yyvsp[-4].numb);
		  compile_functor((yyvsp[-10].text), (yyvsp[-8].text), (yyvsp[-7].numb), str0, str1,
				  (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect);
		}
#line 2124 "parse.cc"
    break;

  case 21: /* statement: T_LABEL K_UDP_S T_STRING ',' T_NUMBER ',' T_NUMBER ',' udp_table ';'  */
#line 211 "parse.y"
                { compile_udp_def(1, (yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-5].numb), (yyvsp[-3].numb), (yyvsp[-1].table)); }
#line 2130 "parse.cc"
    break;

  case 22: /* statement: T_LABEL K_UDP_C T_STRING ',' T_NUMBER ',' udp_table ';'  */
#line 214 "parse.y"
                { compile_udp_def(0, (yyvsp[-7].text), (yyvsp[-5].text), (yyvsp[-3].numb), 0, (yyvsp[-1].table)); }
#line 2136 "parse.cc"
    break;

  case 23: /* statement: T_LABEL K_UDP T_SYMBOL ',' symbols ';'  */
#line 217 "parse.y"
                { compile_udp_functor((yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 2142 "parse.cc"
    break;

  case 24: /* statement: T_LABEL K_ARRAY T_STRING ',' signed_t_number signed_t_number ',' signed_t_number signed_t_number ';'  */
#line 223 "parse.y"
                { compile_var_array((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-5].numb), (yyvsp[-4].numb), (yyvsp[-2].numb), (yyvsp[-1].numb), 0); }
#line 2148 "parse.cc"
    break;

  case 25: /* statement: T_LABEL K_ARRAY_2U T_STRING ',' signed_t_number signed_t_number ',' signed_t_number signed_t_number ';'  */
#line 226 "parse.y"
                { compile_var2_array((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-5].numb), (yyvsp[-4].numb), (yyvsp[-2].numb), (yyvsp[-1].numb), false); }
#line 2154 "parse.cc"
    break;

  case 26: /* statement: T_LABEL K_ARRAY_2S T_STRING ',' signed_t_number signed_t_number ',' signed_t_number signed_t_number ';'  */
#line 228 "parse.y"
                { compile_var2_array((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-5].numb), (yyvsp[-4].numb), (yyvsp[-2].numb), (yyvsp[-1].numb), true); }
#line 2160 "parse.cc"
    break;

  case 27: /* statement: T_LABEL K_ARRAY_I T_STRING ',' signed_t_number signed_t_number ',' signed_t_number signed_t_number ';'  */
#line 231 "parse.y"
                { compile_var_array((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-5].numb), (yyvsp[-4].numb), (yyvsp[-2].numb), (yyvsp[-1].numb), 2); }
#line 2166 "parse.cc"
    break;

  case 28: /* statement: T_LABEL K_ARRAY_R T_STRING ',' signed_t_number signed_t_number ';'  */
#line 234 "parse.y"
                { compile_real_array((yyvsp[-6].text), (yyvsp[-4].text), (yyvsp[-2].numb), (yyvsp[-1].numb)); }
#line 2172 "parse.cc"
    break;

  case 29: /* statement: T_LABEL K_ARRAY_S T_STRING ',' signed_t_number signed_t_number ',' signed_t_number signed_t_number ';'  */
#line 237 "parse.y"
                { compile_var_array((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-5].numb), (yyvsp[-4].numb), (yyvsp[-2].numb), (yyvsp[-1].numb), 1); }
#line 2178 "parse.cc"
    break;

  case 30: /* statement: T_LABEL K_ARRAY_STR T_STRING ',' signed_t_number signed_t_number ';'  */
#line 240 "parse.y"
                { compile_string_array((yyvsp[-6].text), (yyvsp[-4].text), (yyvsp[-2].numb), (yyvsp[-1].numb)); }
#line 2184 "parse.cc"
    break;

  case 31: /* statement: T_LABEL K_ARRAY_OBJ T_STRING ',' signed_t_number signed_t_number ';'  */
#line 243 "parse.y"
                { compile_object_array((yyvsp[-6].text), (yyvsp[-4].text), (yyvsp[-2].numb), (yyvsp[-1].numb)); }
#line 2190 "parse.cc"
    break;

  case 32: /* statement: T_LABEL K_ARRAY T_STRING ',' signed_t_number signed_t_number ';'  */
#line 246 "parse.y"
                { compile_net_array((yyvsp[-6].text), (yyvsp[-4].text), (yyvsp[-2].numb), (yyvsp[-1].numb)); }
#line 2196 "parse.cc"
    break;

  case 33: /* statement: T_LABEL K_ARRAY_PORT T_SYMBOL ',' T_SYMBOL ';'  */
#line 249 "parse.y"
                { compile_array_port((yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].text)); }
#line 2202 "parse.cc"
    break;

  case 34: /* statement: T_LABEL K_ARRAY_PORT T_SYMBOL ',' T_NUMBER ';'  */
#line 252 "parse.y"
                { compile_array_port((yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].numb)); }
#line 2208 "parse.cc"
    break;

  case 35: /* statement: T_LABEL K_ARRAY T_STRING ',' T_SYMBOL ';'  */
#line 255 "parse.y"
                { compile_array_alias((yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].text)); }
#line 2214 "parse.cc"
    break;

  case 36: /* statement: T_LABEL K_UFUNC_REAL T_SYMBOL ',' T_NUMBER ',' T_SYMBOL ';'  */
#line 262 "parse.y"
      { compile_ufunc_real((yyvsp[-7].text), (yyvsp[-5].text), (yyvsp[-3].numb), 0, 0, 0, 0, (yyvsp[-1].text), strdup("E_0x0")); }
#line 2220 "parse.cc"
    break;

  case 37: /* statement: T_LABEL K_UFUNC_REAL T_SYMBOL ',' T_NUMBER ',' symbols '(' symbols ')' T_SYMBOL ';'  */
#line 264 "parse.y"
      { compile_ufunc_real((yyvsp[-11].text), (yyvsp[-9].text), (yyvsp[-7].numb), (yyvsp[-5].symbv).cnt, (yyvsp[-5].symbv).vect, (yyvsp[-3].symbv).cnt, (yyvsp[-3].symbv).vect, (yyvsp[-1].text), 0); }
#line 2226 "parse.cc"
    break;

  case 38: /* statement: T_LABEL K_UFUNC_VEC4 T_SYMBOL ',' T_NUMBER ',' T_SYMBOL ';'  */
#line 267 "parse.y"
      { compile_ufunc_vec4((yyvsp[-7].text), (yyvsp[-5].text), (yyvsp[-3].numb), 0, 0, 0, 0, (yyvsp[-1].text), strdup("E_0x0")); }
#line 2232 "parse.cc"
    break;

  case 39: /* statement: T_LABEL K_UFUNC_VEC4 T_SYMBOL ',' T_NUMBER ',' symbols '(' symbols ')' T_SYMBOL ';'  */
#line 269 "parse.y"
      { compile_ufunc_vec4((yyvsp[-11].text), (yyvsp[-9].text), (yyvsp[-7].numb), (yyvsp[-5].symbv).cnt, (yyvsp[-5].symbv).vect, (yyvsp[-3].symbv).cnt, (yyvsp[-3].symbv).vect, (yyvsp[-1].text), 0); }
#line 2238 "parse.cc"
    break;

  case 40: /* statement: T_LABEL K_UFUNC_E T_SYMBOL ',' T_NUMBER ',' T_SYMBOL ',' symbols '(' symbols ')' T_SYMBOL ';'  */
#line 272 "parse.y"
      { compile_ufunc_vec4((yyvsp[-13].text), (yyvsp[-11].text), (yyvsp[-9].numb), (yyvsp[-5].symbv).cnt, (yyvsp[-5].symbv).vect, (yyvsp[-3].symbv).cnt, (yyvsp[-3].symbv).vect, (yyvsp[-1].text), (yyvsp[-7].text)); }
#line 2244 "parse.cc"
    break;

  case 41: /* statement: T_LABEL K_RESOLV T_SYMBOL ',' symbols ';'  */
#line 278 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_resolver((yyvsp[-5].text), (yyvsp[-3].text), obj.cnt, obj.vect);
		}
#line 2252 "parse.cc"
    break;

  case 42: /* statement: T_LABEL K_PART T_SYMBOL ',' T_NUMBER ',' T_NUMBER ';'  */
#line 286 "parse.y"
                { compile_part_select((yyvsp[-7].text), (yyvsp[-5].text), (yyvsp[-3].numb), (yyvsp[-1].numb)); }
#line 2258 "parse.cc"
    break;

  case 43: /* statement: T_LABEL K_PART_PV T_SYMBOL ',' T_NUMBER ',' T_NUMBER ',' T_NUMBER ';'  */
#line 289 "parse.y"
                { compile_part_select_pv((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-5].numb), (yyvsp[-3].numb), (yyvsp[-1].numb)); }
#line 2264 "parse.cc"
    break;

  case 44: /* statement: T_LABEL K_PART_V T_SYMBOL ',' T_SYMBOL ',' T_NUMBER ';'  */
#line 292 "parse.y"
                { compile_part_select_var((yyvsp[-7].text), (yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].numb), false); }
#line 2270 "parse.cc"
    break;

  case 45: /* statement: T_LABEL K_PART_V_S T_SYMBOL ',' T_SYMBOL ',' T_NUMBER ';'  */
#line 294 "parse.y"
                { compile_part_select_var((yyvsp[-7].text), (yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].numb), true); }
#line 2276 "parse.cc"
    break;

  case 46: /* statement: T_LABEL K_CONCAT '[' T_NUMBER T_NUMBER T_NUMBER T_NUMBER ']' ',' symbols ';'  */
#line 300 "parse.y"
      { compile_concat((yyvsp[-10].text), (yyvsp[-7].numb), (yyvsp[-6].numb), (yyvsp[-5].numb), (yyvsp[-4].numb), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 2282 "parse.cc"
    break;

  case 47: /* statement: T_LABEL K_CONCAT8 '[' T_NUMBER T_NUMBER T_NUMBER T_NUMBER ']' ',' symbols ';'  */
#line 304 "parse.y"
      { compile_concat8((yyvsp[-10].text), (yyvsp[-7].numb), (yyvsp[-6].numb), (yyvsp[-5].numb), (yyvsp[-4].numb), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 2288 "parse.cc"
    break;

  case 48: /* statement: T_LABEL K_SUBSTITUTE T_NUMBER ',' T_NUMBER T_NUMBER ',' symbols ';'  */
#line 308 "parse.y"
      { compile_substitute((yyvsp[-8].text), (yyvsp[-6].numb), (yyvsp[-4].numb), (yyvsp[-3].numb), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 2294 "parse.cc"
    break;

  case 49: /* statement: T_LABEL K_ARITH_ABS symbols ';'  */
#line 314 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_abs((yyvsp[-3].text), obj.cnt, obj.vect);
		}
#line 2302 "parse.cc"
    break;

  case 50: /* statement: T_LABEL K_CAST_INT T_NUMBER ',' symbols ';'  */
#line 319 "parse.y"
      { struct symbv_s obj = (yyvsp[-1].symbv);
	compile_arith_cast_int((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
      }
#line 2310 "parse.cc"
    break;

  case 51: /* statement: T_LABEL K_CAST_REAL symbols ';'  */
#line 324 "parse.y"
      { struct symbv_s obj = (yyvsp[-1].symbv);
	compile_arith_cast_real((yyvsp[-3].text), false, obj.cnt, obj.vect);
      }
#line 2318 "parse.cc"
    break;

  case 52: /* statement: T_LABEL K_CAST_REAL_S symbols ';'  */
#line 329 "parse.y"
      { struct symbv_s obj = (yyvsp[-1].symbv);
	compile_arith_cast_real((yyvsp[-3].text), true, obj.cnt, obj.vect);
      }
#line 2326 "parse.cc"
    break;

  case 53: /* statement: T_LABEL K_CAST_2 T_NUMBER ',' symbols ';'  */
#line 334 "parse.y"
      { struct symbv_s obj = (yyvsp[-1].symbv);
	compile_arith_cast_vec2((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
      }
#line 2334 "parse.cc"
    break;

  case 54: /* statement: T_LABEL K_ARITH_DIV T_NUMBER ',' symbols ';'  */
#line 342 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_div((yyvsp[-5].text), (yyvsp[-3].numb), false, obj.cnt, obj.vect);
		}
#line 2342 "parse.cc"
    break;

  case 55: /* statement: T_LABEL K_ARITH_DIV_R T_NUMBER ',' symbols ';'  */
#line 347 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_div_r((yyvsp[-5].text), obj.cnt, obj.vect);
		}
#line 2350 "parse.cc"
    break;

  case 56: /* statement: T_LABEL K_ARITH_DIV_S T_NUMBER ',' symbols ';'  */
#line 352 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_div((yyvsp[-5].text), (yyvsp[-3].numb), true, obj.cnt, obj.vect);
		}
#line 2358 "parse.cc"
    break;

  case 57: /* statement: T_LABEL K_ARITH_MOD T_NUMBER ',' symbols ';'  */
#line 357 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_mod((yyvsp[-5].text), (yyvsp[-3].numb), false, obj.cnt, obj.vect);
		}
#line 2366 "parse.cc"
    break;

  case 58: /* statement: T_LABEL K_ARITH_MOD_R T_NUMBER ',' symbols ';'  */
#line 362 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_mod_r((yyvsp[-5].text), obj.cnt, obj.vect);
		}
#line 2374 "parse.cc"
    break;

  case 59: /* statement: T_LABEL K_ARITH_MOD_S T_NUMBER ',' symbols ';'  */
#line 367 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_mod((yyvsp[-5].text), (yyvsp[-3].numb), true, obj.cnt, obj.vect);
		}
#line 2382 "parse.cc"
    break;

  case 60: /* statement: T_LABEL K_ARITH_MULT T_NUMBER ',' symbols ';'  */
#line 372 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_mult((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2390 "parse.cc"
    break;

  case 61: /* statement: T_LABEL K_ARITH_MULT_R T_NUMBER ',' symbols ';'  */
#line 377 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_mult_r((yyvsp[-5].text), obj.cnt, obj.vect);
		}
#line 2398 "parse.cc"
    break;

  case 62: /* statement: T_LABEL K_ARITH_POW T_NUMBER ',' symbols ';'  */
#line 382 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_pow((yyvsp[-5].text), (yyvsp[-3].numb), false, obj.cnt, obj.vect);
		}
#line 2406 "parse.cc"
    break;

  case 63: /* statement: T_LABEL K_ARITH_POW_R T_NUMBER ',' symbols ';'  */
#line 387 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_pow_r((yyvsp[-5].text), obj.cnt, obj.vect);
		}
#line 2414 "parse.cc"
    break;

  case 64: /* statement: T_LABEL K_ARITH_POW_S T_NUMBER ',' symbols ';'  */
#line 392 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_pow((yyvsp[-5].text), (yyvsp[-3].numb), true, obj.cnt, obj.vect);
		}
#line 2422 "parse.cc"
    break;

  case 65: /* statement: T_LABEL K_ARITH_SUB T_NUMBER ',' symbols ';'  */
#line 397 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_sub((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2430 "parse.cc"
    break;

  case 66: /* statement: T_LABEL K_ARITH_SUB_R T_NUMBER ',' symbols ';'  */
#line 402 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_sub_r((yyvsp[-5].text), obj.cnt, obj.vect);
		}
#line 2438 "parse.cc"
    break;

  case 67: /* statement: T_LABEL K_ARITH_SUM T_NUMBER ',' symbols ';'  */
#line 407 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_sum((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2446 "parse.cc"
    break;

  case 68: /* statement: T_LABEL K_ARITH_SUM_R T_NUMBER ',' symbols ';'  */
#line 412 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_arith_sum_r((yyvsp[-5].text), obj.cnt, obj.vect);
		}
#line 2454 "parse.cc"
    break;

  case 69: /* statement: T_LABEL K_CMP_EEQ T_NUMBER ',' symbols ';'  */
#line 417 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_eeq((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2462 "parse.cc"
    break;

  case 70: /* statement: T_LABEL K_CMP_NEE T_NUMBER ',' symbols ';'  */
#line 422 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_nee((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2470 "parse.cc"
    break;

  case 71: /* statement: T_LABEL K_CMP_EQ T_NUMBER ',' symbols ';'  */
#line 427 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_eq((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2478 "parse.cc"
    break;

  case 72: /* statement: T_LABEL K_CMP_EQX T_NUMBER ',' symbols ';'  */
#line 432 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_eqx((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2486 "parse.cc"
    break;

  case 73: /* statement: T_LABEL K_CMP_EQZ T_NUMBER ',' symbols ';'  */
#line 437 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_eqz((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2494 "parse.cc"
    break;

  case 74: /* statement: T_LABEL K_CMP_EQ_R T_NUMBER ',' symbols ';'  */
#line 442 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_eq_r((yyvsp[-5].text), obj.cnt, obj.vect);
		}
#line 2502 "parse.cc"
    break;

  case 75: /* statement: T_LABEL K_CMP_NE T_NUMBER ',' symbols ';'  */
#line 447 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_ne((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2510 "parse.cc"
    break;

  case 76: /* statement: T_LABEL K_CMP_NE_R T_NUMBER ',' symbols ';'  */
#line 452 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_ne_r((yyvsp[-5].text), obj.cnt, obj.vect);
		}
#line 2518 "parse.cc"
    break;

  case 77: /* statement: T_LABEL K_CMP_GE T_NUMBER ',' symbols ';'  */
#line 457 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_ge((yyvsp[-5].text), (yyvsp[-3].numb), false, obj.cnt, obj.vect);
		}
#line 2526 "parse.cc"
    break;

  case 78: /* statement: T_LABEL K_CMP_GE_R T_NUMBER ',' symbols ';'  */
#line 462 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_ge_r((yyvsp[-5].text), obj.cnt, obj.vect);
		}
#line 2534 "parse.cc"
    break;

  case 79: /* statement: T_LABEL K_CMP_GE_S T_NUMBER ',' symbols ';'  */
#line 467 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_ge((yyvsp[-5].text), (yyvsp[-3].numb), true, obj.cnt, obj.vect);
		}
#line 2542 "parse.cc"
    break;

  case 80: /* statement: T_LABEL K_CMP_GT T_NUMBER ',' symbols ';'  */
#line 472 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_gt((yyvsp[-5].text), (yyvsp[-3].numb), false, obj.cnt, obj.vect);
		}
#line 2550 "parse.cc"
    break;

  case 81: /* statement: T_LABEL K_CMP_GT_R T_NUMBER ',' symbols ';'  */
#line 477 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_gt_r((yyvsp[-5].text), obj.cnt, obj.vect);
		}
#line 2558 "parse.cc"
    break;

  case 82: /* statement: T_LABEL K_CMP_GT_S T_NUMBER ',' symbols ';'  */
#line 482 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_gt((yyvsp[-5].text), (yyvsp[-3].numb), true, obj.cnt, obj.vect);
		}
#line 2566 "parse.cc"
    break;

  case 83: /* statement: T_LABEL K_CMP_WEQ T_NUMBER ',' symbols ';'  */
#line 487 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_weq((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2574 "parse.cc"
    break;

  case 84: /* statement: T_LABEL K_CMP_WNE T_NUMBER ',' symbols ';'  */
#line 492 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_cmp_wne((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2582 "parse.cc"
    break;

  case 85: /* statement: T_LABEL K_DELAY T_NUMBER delay symbol ';'  */
#line 501 "parse.y"
    { compile_delay((yyvsp[-5].text), (yyvsp[-3].numb), (yyvsp[-2].cdelay), (yyvsp[-1].symb)); }
#line 2588 "parse.cc"
    break;

  case 86: /* statement: T_LABEL K_DELAY T_NUMBER symbols ';'  */
#line 503 "parse.y"
    { struct symbv_s obj = (yyvsp[-1].symbv);
      compile_delay((yyvsp[-4].text), (yyvsp[-2].numb), obj.cnt, obj.vect, false);
    }
#line 2596 "parse.cc"
    break;

  case 87: /* statement: T_LABEL K_DELAY T_NUMBER symbols ',' T_NUMBER ';'  */
#line 507 "parse.y"
    { struct symbv_s obj = (yyvsp[-3].symbv);
      if ((yyvsp[-1].numb) != 0) assert(0);
      compile_delay((yyvsp[-6].text), (yyvsp[-4].numb), obj.cnt, obj.vect, true);
    }
#line 2605 "parse.cc"
    break;

  case 88: /* $@2: %empty  */
#line 513 "parse.y"
    { modpath_dst = compile_modpath((yyvsp[-5].text), (yyvsp[-3].numb), (yyvsp[-2].symb), (yyvsp[-1].symb)); }
#line 2611 "parse.cc"
    break;

  case 89: /* statement: T_LABEL K_MODPATH T_NUMBER symbol symbol ',' $@2 modpath_src_list ';'  */
#line 515 "parse.y"
    { modpath_dst = 0; }
#line 2617 "parse.cc"
    break;

  case 90: /* statement: T_LABEL K_DFF_N T_NUMBER symbol ',' symbol ',' symbol ';'  */
#line 520 "parse.y"
      { compile_dff((yyvsp[-8].text), (yyvsp[-6].numb), true, (yyvsp[-5].symb), (yyvsp[-3].symb), (yyvsp[-1].symb)); }
#line 2623 "parse.cc"
    break;

  case 91: /* statement: T_LABEL K_DFF_P T_NUMBER symbol ',' symbol ',' symbol ';'  */
#line 523 "parse.y"
      { compile_dff((yyvsp[-8].text), (yyvsp[-6].numb), false, (yyvsp[-5].symb), (yyvsp[-3].symb), (yyvsp[-1].symb)); }
#line 2629 "parse.cc"
    break;

  case 92: /* statement: T_LABEL K_DFF_N_ACLR T_NUMBER symbol ',' symbol ',' symbol ',' symbol ';'  */
#line 526 "parse.y"
      { compile_dff_aclr((yyvsp[-10].text), (yyvsp[-8].numb), true, (yyvsp[-7].symb), (yyvsp[-5].symb), (yyvsp[-3].symb), (yyvsp[-1].symb)); }
#line 2635 "parse.cc"
    break;

  case 93: /* statement: T_LABEL K_DFF_P_ACLR T_NUMBER symbol ',' symbol ',' symbol ',' symbol ';'  */
#line 529 "parse.y"
      { compile_dff_aclr((yyvsp[-10].text), (yyvsp[-8].numb), false, (yyvsp[-7].symb), (yyvsp[-5].symb), (yyvsp[-3].symb), (yyvsp[-1].symb)); }
#line 2641 "parse.cc"
    break;

  case 94: /* statement: T_LABEL K_DFF_N_ASET T_NUMBER symbol ',' symbol ',' symbol ',' symbol ';'  */
#line 532 "parse.y"
      { compile_dff_aset((yyvsp[-10].text), (yyvsp[-8].numb), true, (yyvsp[-7].symb), (yyvsp[-5].symb), (yyvsp[-3].symb), (yyvsp[-1].symb), 0); }
#line 2647 "parse.cc"
    break;

  case 95: /* statement: T_LABEL K_DFF_P_ASET T_NUMBER symbol ',' symbol ',' symbol ',' symbol ';'  */
#line 535 "parse.y"
      { compile_dff_aset((yyvsp[-10].text), (yyvsp[-8].numb), false, (yyvsp[-7].symb), (yyvsp[-5].symb), (yyvsp[-3].symb), (yyvsp[-1].symb), 0); }
#line 2653 "parse.cc"
    break;

  case 96: /* statement: T_LABEL K_DFF_N_ASET T_NUMBER symbol ',' symbol ',' symbol ',' symbol ',' T_SYMBOL ';'  */
#line 538 "parse.y"
      { compile_dff_aset((yyvsp[-12].text), (yyvsp[-10].numb), true, (yyvsp[-9].symb), (yyvsp[-7].symb), (yyvsp[-5].symb), (yyvsp[-3].symb), (yyvsp[-1].text)); }
#line 2659 "parse.cc"
    break;

  case 97: /* statement: T_LABEL K_DFF_P_ASET T_NUMBER symbol ',' symbol ',' symbol ',' symbol ',' T_SYMBOL ';'  */
#line 541 "parse.y"
      { compile_dff_aset((yyvsp[-12].text), (yyvsp[-10].numb), false, (yyvsp[-9].symb), (yyvsp[-7].symb), (yyvsp[-5].symb), (yyvsp[-3].symb), (yyvsp[-1].text)); }
#line 2665 "parse.cc"
    break;

  case 98: /* statement: T_LABEL K_LATCH T_NUMBER symbol ',' symbol ';'  */
#line 546 "parse.y"
      { compile_latch((yyvsp[-6].text), (yyvsp[-4].numb), (yyvsp[-3].symb), (yyvsp[-1].symb)); }
#line 2671 "parse.cc"
    break;

  case 99: /* statement: T_LABEL K_REDUCE_AND symbol ';'  */
#line 551 "parse.y"
                { compile_reduce_and((yyvsp[-3].text), (yyvsp[-1].symb)); }
#line 2677 "parse.cc"
    break;

  case 100: /* statement: T_LABEL K_REDUCE_OR symbol ';'  */
#line 554 "parse.y"
                { compile_reduce_or((yyvsp[-3].text), (yyvsp[-1].symb)); }
#line 2683 "parse.cc"
    break;

  case 101: /* statement: T_LABEL K_REDUCE_XOR symbol ';'  */
#line 557 "parse.y"
                { compile_reduce_xor((yyvsp[-3].text), (yyvsp[-1].symb)); }
#line 2689 "parse.cc"
    break;

  case 102: /* statement: T_LABEL K_REDUCE_NAND symbol ';'  */
#line 560 "parse.y"
                { compile_reduce_nand((yyvsp[-3].text), (yyvsp[-1].symb)); }
#line 2695 "parse.cc"
    break;

  case 103: /* statement: T_LABEL K_REDUCE_NOR symbol ';'  */
#line 563 "parse.y"
                { compile_reduce_nor((yyvsp[-3].text), (yyvsp[-1].symb)); }
#line 2701 "parse.cc"
    break;

  case 104: /* statement: T_LABEL K_REDUCE_XNOR symbol ';'  */
#line 566 "parse.y"
                { compile_reduce_xnor((yyvsp[-3].text), (yyvsp[-1].symb)); }
#line 2707 "parse.cc"
    break;

  case 105: /* statement: T_LABEL K_REPEAT T_NUMBER ',' T_NUMBER ',' symbol ';'  */
#line 569 "parse.y"
                { compile_repeat((yyvsp[-7].text), (yyvsp[-5].numb), (yyvsp[-3].numb), (yyvsp[-1].symb)); }
#line 2713 "parse.cc"
    break;

  case 106: /* statement: T_LABEL K_EXTEND_S T_NUMBER ',' symbol ';'  */
#line 574 "parse.y"
                { compile_extend_signed((yyvsp[-5].text), (yyvsp[-3].numb), (yyvsp[-1].symb)); }
#line 2719 "parse.cc"
    break;

  case 107: /* statement: T_LABEL K_SFUNC T_NUMBER T_NUMBER T_STRING ',' T_STRING ',' symbols ';'  */
#line 579 "parse.y"
                { compile_sfunc((yyvsp[-9].text), (yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-7].numb), (yyvsp[-6].numb), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect, 0); }
#line 2725 "parse.cc"
    break;

  case 108: /* statement: T_LABEL K_SFUNC_E T_NUMBER T_NUMBER T_STRING ',' T_SYMBOL ',' T_STRING ',' symbols ';'  */
#line 583 "parse.y"
                { compile_sfunc((yyvsp[-11].text), (yyvsp[-7].text), (yyvsp[-3].text), (yyvsp[-9].numb), (yyvsp[-8].numb), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect, (yyvsp[-5].text)); }
#line 2731 "parse.cc"
    break;

  case 109: /* statement: T_LABEL K_SFUNC T_NUMBER T_NUMBER T_STRING ',' T_STRING ';'  */
#line 588 "parse.y"
                { compile_sfunc((yyvsp[-7].text), (yyvsp[-3].text), (yyvsp[-1].text), (yyvsp[-5].numb), (yyvsp[-4].numb), 0, 0, 0); }
#line 2737 "parse.cc"
    break;

  case 110: /* statement: T_LABEL K_SFUNC_E T_NUMBER T_NUMBER T_STRING ',' T_SYMBOL ',' T_STRING ';'  */
#line 592 "parse.y"
                { compile_sfunc((yyvsp[-9].text), (yyvsp[-5].text), (yyvsp[-1].text), (yyvsp[-7].numb), (yyvsp[-6].numb), 0, 0, (yyvsp[-3].text)); }
#line 2743 "parse.cc"
    break;

  case 111: /* statement: T_LABEL K_SHIFTL T_NUMBER ',' symbols ';'  */
#line 597 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		  compile_shiftl((yyvsp[-5].text), (yyvsp[-3].numb), obj.cnt, obj.vect);
		}
#line 2751 "parse.cc"
    break;

  case 112: /* statement: T_LABEL K_SHIFTR T_NUMBER ',' symbols ';'  */
#line 602 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		      compile_shiftr((yyvsp[-5].text), (yyvsp[-3].numb), false, obj.cnt, obj.vect);
		}
#line 2759 "parse.cc"
    break;

  case 113: /* statement: T_LABEL K_SHIFTRS T_NUMBER ',' symbols ';'  */
#line 608 "parse.y"
                { struct symbv_s obj = (yyvsp[-1].symbv);
		      compile_shiftr((yyvsp[-5].text), (yyvsp[-3].numb), true, obj.cnt, obj.vect);
		}
#line 2767 "parse.cc"
    break;

  case 114: /* statement: T_LABEL K_EVENT T_SYMBOL ',' symbols ';'  */
#line 618 "parse.y"
                { compile_event((yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 2773 "parse.cc"
    break;

  case 115: /* statement: T_LABEL K_EVENT K_DEBUG T_SYMBOL ',' symbols ';'  */
#line 621 "parse.y"
                { compile_event((yyvsp[-6].text), (yyvsp[-3].text), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 2779 "parse.cc"
    break;

  case 116: /* statement: T_LABEL K_EVENT T_STRING ';'  */
#line 624 "parse.y"
                { compile_named_event((yyvsp[-3].text), (yyvsp[-1].text)); }
#line 2785 "parse.cc"
    break;

  case 117: /* statement: T_LABEL K_EVENT_OR symbols ';'  */
#line 627 "parse.y"
                { compile_event((yyvsp[-3].text), 0, (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 2791 "parse.cc"
    break;

  case 118: /* statement: label_opt T_INSTR operands_opt ';'  */
#line 635 "parse.y"
                { compile_code((yyvsp[-3].text), (yyvsp[-2].text), (yyvsp[-1].opa)); }
#line 2797 "parse.cc"
    break;

  case 119: /* statement: T_LABEL ';'  */
#line 638 "parse.y"
                { compile_codelabel((yyvsp[-1].text)); }
#line 2803 "parse.cc"
    break;

  case 120: /* statement: label_opt K_file_line T_NUMBER T_NUMBER T_STRING ';'  */
#line 643 "parse.y"
                { compile_file_line((yyvsp[-5].text), (yyvsp[-3].numb), (yyvsp[-2].numb), (yyvsp[-1].text)); }
#line 2809 "parse.cc"
    break;

  case 121: /* statement: label_opt K_file_line T_NUMBER T_NUMBER T_NUMBER ';'  */
#line 646 "parse.y"
                { assert((yyvsp[-1].numb) == 0);
		  compile_file_line((yyvsp[-5].text), (yyvsp[-3].numb), (yyvsp[-2].numb), 0); }
#line 2816 "parse.cc"
    break;

  case 122: /* statement: label_opt K_vpi_call T_NUMBER T_NUMBER T_STRING argument_opt '{' T_NUMBER T_NUMBER T_NUMBER '}' ';'  */
#line 657 "parse.y"
      { compile_vpi_call((yyvsp[-11].text), (yyvsp[-7].text), true, false, (yyvsp[-9].numb), (yyvsp[-8].numb),
			 (yyvsp[-6].argv).argc, (yyvsp[-6].argv).argv, (yyvsp[-4].numb), (yyvsp[-3].numb), (yyvsp[-2].numb)); }
#line 2823 "parse.cc"
    break;

  case 123: /* statement: label_opt K_vpi_call_w T_NUMBER T_NUMBER T_STRING argument_opt '{' T_NUMBER T_NUMBER T_NUMBER '}' ';'  */
#line 664 "parse.y"
      { compile_vpi_call((yyvsp[-11].text), (yyvsp[-7].text), false, true, (yyvsp[-9].numb), (yyvsp[-8].numb),
			 (yyvsp[-6].argv).argc, (yyvsp[-6].argv).argv, (yyvsp[-4].numb), (yyvsp[-3].numb), (yyvsp[-2].numb)); }
#line 2830 "parse.cc"
    break;

  case 124: /* statement: label_opt K_vpi_call_i T_NUMBER T_NUMBER T_STRING argument_opt '{' T_NUMBER T_NUMBER T_NUMBER '}' ';'  */
#line 671 "parse.y"
      { compile_vpi_call((yyvsp[-11].text), (yyvsp[-7].text), false, false, (yyvsp[-9].numb), (yyvsp[-8].numb),
			 (yyvsp[-6].argv).argc, (yyvsp[-6].argv).argv, (yyvsp[-4].numb), (yyvsp[-3].numb), (yyvsp[-2].numb)); }
#line 2837 "parse.cc"
    break;

  case 125: /* statement: label_opt K_vpi_func T_NUMBER T_NUMBER T_STRING T_NUMBER argument_opt '{' T_NUMBER T_NUMBER T_NUMBER '}' ';'  */
#line 676 "parse.y"
      { compile_vpi_func_call((yyvsp[-12].text), (yyvsp[-8].text), -vpiVectorVal, (yyvsp[-7].numb), (yyvsp[-10].numb), (yyvsp[-9].numb),
			      (yyvsp[-6].argv).argc, (yyvsp[-6].argv).argv, (yyvsp[-4].numb), (yyvsp[-3].numb), (yyvsp[-2].numb)); }
#line 2844 "parse.cc"
    break;

  case 126: /* statement: label_opt K_vpi_func_r T_NUMBER T_NUMBER T_STRING argument_opt '{' T_NUMBER T_NUMBER T_NUMBER '}' ';'  */
#line 681 "parse.y"
      { compile_vpi_func_call((yyvsp[-11].text), (yyvsp[-7].text), -vpiRealVal, 0, (yyvsp[-9].numb), (yyvsp[-8].numb),
			      (yyvsp[-6].argv).argc, (yyvsp[-6].argv).argv, (yyvsp[-4].numb), (yyvsp[-3].numb), (yyvsp[-2].numb)); }
#line 2851 "parse.cc"
    break;

  case 127: /* statement: label_opt K_vpi_func_s T_NUMBER T_NUMBER T_STRING argument_opt '{' T_NUMBER T_NUMBER T_NUMBER '}' ';'  */
#line 686 "parse.y"
      { compile_vpi_func_call((yyvsp[-11].text), (yyvsp[-7].text), -vpiStringVal, 0, (yyvsp[-9].numb), (yyvsp[-8].numb),
			      (yyvsp[-6].argv).argc, (yyvsp[-6].argv).argv, (yyvsp[-4].numb), (yyvsp[-3].numb), (yyvsp[-2].numb)); }
#line 2858 "parse.cc"
    break;

  case 128: /* statement: T_LABEL K_SCOPE T_SYMBOL ',' T_STRING T_STRING T_NUMBER T_NUMBER ';'  */
#line 705 "parse.y"
                { compile_scope_decl((yyvsp[-8].text), (yyvsp[-6].text), (yyvsp[-4].text), (yyvsp[-3].text), 0, (yyvsp[-2].numb), (yyvsp[-1].numb), (yyvsp[-2].numb), (yyvsp[-1].numb), 0); }
#line 2864 "parse.cc"
    break;

  case 129: /* statement: T_LABEL K_SCOPE T_SYMBOL ',' T_STRING T_STRING T_NUMBER T_NUMBER ',' T_NUMBER T_NUMBER T_NUMBER ',' T_SYMBOL ';'  */
#line 709 "parse.y"
                { compile_scope_decl((yyvsp[-14].text), (yyvsp[-12].text), (yyvsp[-10].text), (yyvsp[-9].text), (yyvsp[-1].text), (yyvsp[-8].numb), (yyvsp[-7].numb), (yyvsp[-5].numb), (yyvsp[-4].numb), (yyvsp[-3].numb)); }
#line 2870 "parse.cc"
    break;

  case 130: /* statement: K_SCOPE T_SYMBOL ';'  */
#line 715 "parse.y"
                { compile_scope_recall((yyvsp[-1].text)); }
#line 2876 "parse.cc"
    break;

  case 131: /* statement: K_PORT_INFO T_NUMBER port_type T_NUMBER T_STRING T_SYMBOL ';'  */
#line 721 "parse.y"
                { compile_port_info( (yyvsp[-5].numb) /* port_index */, (yyvsp[-4].vpi_enum), (yyvsp[-3].numb) /* width */,
		                     (yyvsp[-2].text) /*&name */, (yyvsp[-1].text) /* buffer */ ); }
#line 2883 "parse.cc"
    break;

  case 132: /* statement: K_PORT_INFO T_NUMBER port_type T_NUMBER T_STRING ';'  */
#line 725 "parse.y"
                { compile_port_info( (yyvsp[-4].numb) /* port_index */, (yyvsp[-3].vpi_enum), (yyvsp[-2].numb) /* width */,
		                     (yyvsp[-1].text) /*&name */, nullptr /* buffer */ ); }
#line 2890 "parse.cc"
    break;

  case 133: /* statement: K_TIMESCALE T_NUMBER T_NUMBER ';'  */
#line 729 "parse.y"
                { compile_timescale((yyvsp[-2].numb), (yyvsp[-1].numb)); }
#line 2896 "parse.cc"
    break;

  case 134: /* statement: K_TIMESCALE '-' T_NUMBER T_NUMBER ';'  */
#line 731 "parse.y"
                { compile_timescale(-(yyvsp[-2].numb), (yyvsp[-1].numb)); }
#line 2902 "parse.cc"
    break;

  case 135: /* statement: K_TIMESCALE T_NUMBER '-' T_NUMBER ';'  */
#line 733 "parse.y"
                { compile_timescale((yyvsp[-3].numb), -(yyvsp[-1].numb)); }
#line 2908 "parse.cc"
    break;

  case 136: /* statement: K_TIMESCALE '-' T_NUMBER '-' T_NUMBER ';'  */
#line 735 "parse.y"
                { compile_timescale(-(yyvsp[-3].numb), -(yyvsp[-1].numb)); }
#line 2914 "parse.cc"
    break;

  case 137: /* statement: K_THREAD T_SYMBOL ';'  */
#line 742 "parse.y"
                { compile_thread((yyvsp[-1].text), 0); }
#line 2920 "parse.cc"
    break;

  case 138: /* statement: K_THREAD T_SYMBOL ',' T_SYMBOL ';'  */
#line 745 "parse.y"
                { compile_thread((yyvsp[-3].text), (yyvsp[-1].text)); }
#line 2926 "parse.cc"
    break;

  case 139: /* statement: T_LABEL K_VAR local_flag T_STRING ',' signed_t_number signed_t_number ';'  */
#line 752 "parse.y"
      { compile_variable((yyvsp[-7].text), (yyvsp[-4].text), (yyvsp[-2].numb), (yyvsp[-1].numb), vpiLogicVar, false, (yyvsp[-5].flag)); }
#line 2932 "parse.cc"
    break;

  case 140: /* statement: T_LABEL K_VAR_S local_flag T_STRING ',' signed_t_number signed_t_number ';'  */
#line 755 "parse.y"
      { compile_variable((yyvsp[-7].text), (yyvsp[-4].text), (yyvsp[-2].numb), (yyvsp[-1].numb), vpiLogicVar, true, (yyvsp[-5].flag)); }
#line 2938 "parse.cc"
    break;

  case 141: /* statement: T_LABEL K_VAR_I local_flag T_STRING ',' T_NUMBER T_NUMBER ';'  */
#line 758 "parse.y"
      { compile_variable((yyvsp[-7].text), (yyvsp[-4].text), (yyvsp[-2].numb), (yyvsp[-1].numb), vpiIntegerVar, true, (yyvsp[-5].flag)); }
#line 2944 "parse.cc"
    break;

  case 142: /* statement: T_LABEL K_VAR_2S local_flag T_STRING ',' signed_t_number signed_t_number ';'  */
#line 761 "parse.y"
      { compile_variable((yyvsp[-7].text), (yyvsp[-4].text), (yyvsp[-2].numb), (yyvsp[-1].numb), vpiIntVar, true, (yyvsp[-5].flag)); }
#line 2950 "parse.cc"
    break;

  case 143: /* statement: T_LABEL K_VAR_2U local_flag T_STRING ',' signed_t_number signed_t_number ';'  */
#line 764 "parse.y"
      { compile_variable((yyvsp[-7].text), (yyvsp[-4].text), (yyvsp[-2].numb), (yyvsp[-1].numb), vpiIntVar, false, (yyvsp[-5].flag)); }
#line 2956 "parse.cc"
    break;

  case 144: /* statement: T_LABEL K_VAR_R T_STRING ',' signed_t_number signed_t_number ';'  */
#line 767 "parse.y"
      { compile_var_real((yyvsp[-6].text), (yyvsp[-4].text)); }
#line 2962 "parse.cc"
    break;

  case 145: /* statement: T_LABEL K_VAR_STR T_STRING ';'  */
#line 770 "parse.y"
      { compile_var_string((yyvsp[-3].text), (yyvsp[-1].text)); }
#line 2968 "parse.cc"
    break;

  case 146: /* statement: T_LABEL K_VAR_DARRAY T_STRING ',' T_NUMBER ';'  */
#line 773 "parse.y"
      { compile_var_darray((yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].numb)); }
#line 2974 "parse.cc"
    break;

  case 147: /* statement: T_LABEL K_VAR_QUEUE T_STRING ',' T_NUMBER ';'  */
#line 776 "parse.y"
      { compile_var_queue((yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].numb)); }
#line 2980 "parse.cc"
    break;

  case 148: /* statement: T_LABEL K_VAR_COBJECT T_STRING ';'  */
#line 779 "parse.y"
      { compile_var_cobject((yyvsp[-3].text), (yyvsp[-1].text)); }
#line 2986 "parse.cc"
    break;

  case 149: /* statement: T_LABEL K_NET local_flag T_STRING ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 786 "parse.y"
      { compile_net((yyvsp[-9].text), (yyvsp[-6].text), (yyvsp[-4].numb), (yyvsp[-3].numb), vpiLogicVar, false, (yyvsp[-7].flag), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 2992 "parse.cc"
    break;

  case 150: /* statement: T_LABEL K_NET_S local_flag T_STRING ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 790 "parse.y"
      { compile_net((yyvsp[-9].text), (yyvsp[-6].text), (yyvsp[-4].numb), (yyvsp[-3].numb), vpiLogicVar, true, (yyvsp[-7].flag), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 2998 "parse.cc"
    break;

  case 151: /* statement: T_LABEL K_NET_2U local_flag T_STRING ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 794 "parse.y"
      { compile_net((yyvsp[-9].text), (yyvsp[-6].text), (yyvsp[-4].numb), (yyvsp[-3].numb), vpiIntVar, false, (yyvsp[-7].flag), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3004 "parse.cc"
    break;

  case 152: /* statement: T_LABEL K_NET_2S local_flag T_STRING ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 798 "parse.y"
      { compile_net((yyvsp[-9].text), (yyvsp[-6].text), (yyvsp[-4].numb), (yyvsp[-3].numb), vpiIntVar, true, (yyvsp[-7].flag), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3010 "parse.cc"
    break;

  case 153: /* statement: T_LABEL K_NET8 local_flag T_STRING ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 802 "parse.y"
      { compile_net((yyvsp[-9].text), (yyvsp[-6].text), (yyvsp[-4].numb), (yyvsp[-3].numb), -vpiLogicVar, false, (yyvsp[-7].flag), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3016 "parse.cc"
    break;

  case 154: /* statement: T_LABEL K_NET8_2U local_flag T_STRING ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 806 "parse.y"
      { compile_net((yyvsp[-9].text), (yyvsp[-6].text), (yyvsp[-4].numb), (yyvsp[-3].numb), -vpiLogicVar, false, (yyvsp[-7].flag), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3022 "parse.cc"
    break;

  case 155: /* statement: T_LABEL K_NET8_S local_flag T_STRING ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 810 "parse.y"
      { compile_net((yyvsp[-9].text), (yyvsp[-6].text), (yyvsp[-4].numb), (yyvsp[-3].numb), -vpiLogicVar, true, (yyvsp[-7].flag), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3028 "parse.cc"
    break;

  case 156: /* statement: T_LABEL K_NET8_2S local_flag T_STRING ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 814 "parse.y"
      { compile_net((yyvsp[-9].text), (yyvsp[-6].text), (yyvsp[-4].numb), (yyvsp[-3].numb), -vpiLogicVar, true, (yyvsp[-7].flag), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3034 "parse.cc"
    break;

  case 157: /* statement: T_LABEL K_NET_R local_flag T_STRING ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 818 "parse.y"
      { compile_net_real((yyvsp[-9].text), (yyvsp[-6].text), (yyvsp[-4].numb), (yyvsp[-3].numb), (yyvsp[-7].flag), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3040 "parse.cc"
    break;

  case 158: /* statement: T_LABEL K_NET T_SYMBOL T_NUMBER ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 824 "parse.y"
      { compile_netw((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-6].numb), (yyvsp[-4].numb), (yyvsp[-3].numb), vpiLogicVar, false, (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3046 "parse.cc"
    break;

  case 159: /* statement: T_LABEL K_NET_S T_SYMBOL T_NUMBER ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 828 "parse.y"
      { compile_netw((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-6].numb), (yyvsp[-4].numb), (yyvsp[-3].numb), vpiLogicVar, true, (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3052 "parse.cc"
    break;

  case 160: /* statement: T_LABEL K_NET_2U T_SYMBOL T_NUMBER ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 832 "parse.y"
      { compile_netw((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-6].numb), (yyvsp[-4].numb), (yyvsp[-3].numb), vpiIntVar, false, (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3058 "parse.cc"
    break;

  case 161: /* statement: T_LABEL K_NET_2S T_SYMBOL T_NUMBER ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 836 "parse.y"
      { compile_netw((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-6].numb), (yyvsp[-4].numb), (yyvsp[-3].numb), vpiIntVar, true, (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3064 "parse.cc"
    break;

  case 162: /* statement: T_LABEL K_NET8 T_SYMBOL T_NUMBER ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 840 "parse.y"
      { compile_netw((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-6].numb), (yyvsp[-4].numb), (yyvsp[-3].numb), -vpiLogicVar, false, (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3070 "parse.cc"
    break;

  case 163: /* statement: T_LABEL K_NET8_S T_SYMBOL T_NUMBER ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 844 "parse.y"
      { compile_netw((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-6].numb), (yyvsp[-4].numb), (yyvsp[-3].numb), -vpiLogicVar, true, (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3076 "parse.cc"
    break;

  case 164: /* statement: T_LABEL K_NET_R T_SYMBOL T_NUMBER ',' signed_t_number signed_t_number ',' symbols_net ';'  */
#line 848 "parse.y"
      { compile_netw_real((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-6].numb), (yyvsp[-4].numb), (yyvsp[-3].numb), (yyvsp[-1].symbv).cnt, (yyvsp[-1].symbv).vect); }
#line 3082 "parse.cc"
    break;

  case 165: /* statement: T_LABEL K_PARAM_STR T_STRING T_NUMBER T_NUMBER T_NUMBER ',' T_STRING ';'  */
#line 854 "parse.y"
                { compile_param_string((yyvsp[-8].text), (yyvsp[-6].text), (yyvsp[-1].text), (yyvsp[-5].numb), (yyvsp[-4].numb), (yyvsp[-3].numb)); }
#line 3088 "parse.cc"
    break;

  case 166: /* statement: T_LABEL K_PARAM_L T_STRING T_NUMBER T_NUMBER T_NUMBER ',' T_SYMBOL ';'  */
#line 857 "parse.y"
                { compile_param_logic((yyvsp[-8].text), (yyvsp[-6].text), (yyvsp[-1].text), false, (yyvsp[-5].numb), (yyvsp[-4].numb), (yyvsp[-3].numb)); }
#line 3094 "parse.cc"
    break;

  case 167: /* statement: T_LABEL K_PARAM_L T_STRING T_NUMBER T_NUMBER T_NUMBER ',' '+' T_SYMBOL ';'  */
#line 860 "parse.y"
                { compile_param_logic((yyvsp[-9].text), (yyvsp[-7].text), (yyvsp[-1].text), true, (yyvsp[-6].numb), (yyvsp[-5].numb), (yyvsp[-4].numb) ); }
#line 3100 "parse.cc"
    break;

  case 168: /* statement: T_LABEL K_PARAM_REAL T_STRING T_NUMBER T_NUMBER T_NUMBER ',' T_SYMBOL ';'  */
#line 863 "parse.y"
                { compile_param_real((yyvsp[-8].text), (yyvsp[-6].text), (yyvsp[-1].text), (yyvsp[-5].numb), (yyvsp[-4].numb), (yyvsp[-3].numb)); }
#line 3106 "parse.cc"
    break;

  case 169: /* statement: T_LABEL K_ISLAND T_SYMBOL ';'  */
#line 868 "parse.y"
      { compile_island((yyvsp[-3].text), (yyvsp[-1].text)); }
#line 3112 "parse.cc"
    break;

  case 170: /* statement: T_LABEL K_PORT T_SYMBOL ',' T_SYMBOL ';'  */
#line 871 "parse.y"
      { compile_island_port((yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].text)); }
#line 3118 "parse.cc"
    break;

  case 171: /* statement: T_LABEL K_IMPORT T_SYMBOL ',' T_SYMBOL ';'  */
#line 874 "parse.y"
      { compile_island_import((yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].text)); }
#line 3124 "parse.cc"
    break;

  case 172: /* statement: T_LABEL K_EXPORT T_SYMBOL ';'  */
#line 877 "parse.y"
      { compile_island_export((yyvsp[-3].text), (yyvsp[-1].text)); }
#line 3130 "parse.cc"
    break;

  case 173: /* statement: K_RTRAN T_SYMBOL ',' T_SYMBOL T_SYMBOL ';'  */
#line 880 "parse.y"
      { compile_island_tranif(0, (yyvsp[-4].text), (yyvsp[-2].text), (yyvsp[-1].text), 0, 1); }
#line 3136 "parse.cc"
    break;

  case 174: /* statement: K_RTRANIF0 T_SYMBOL ',' T_SYMBOL T_SYMBOL ',' T_SYMBOL ';'  */
#line 883 "parse.y"
      { compile_island_tranif(0, (yyvsp[-6].text), (yyvsp[-4].text), (yyvsp[-3].text), (yyvsp[-1].text), 1); }
#line 3142 "parse.cc"
    break;

  case 175: /* statement: K_RTRANIF1 T_SYMBOL ',' T_SYMBOL T_SYMBOL ',' T_SYMBOL ';'  */
#line 886 "parse.y"
      { compile_island_tranif(1, (yyvsp[-6].text), (yyvsp[-4].text), (yyvsp[-3].text), (yyvsp[-1].text), 1); }
#line 3148 "parse.cc"
    break;

  case 176: /* statement: K_TRAN T_SYMBOL ',' T_SYMBOL T_SYMBOL ';'  */
#line 889 "parse.y"
      { compile_island_tranif(0, (yyvsp[-4].text), (yyvsp[-2].text), (yyvsp[-1].text), 0, 0); }
#line 3154 "parse.cc"
    break;

  case 177: /* statement: K_TRANIF0 T_SYMBOL ',' T_SYMBOL T_SYMBOL ',' T_SYMBOL ';'  */
#line 892 "parse.y"
      { compile_island_tranif(0, (yyvsp[-6].text), (yyvsp[-4].text), (yyvsp[-3].text), (yyvsp[-1].text), 0); }
#line 3160 "parse.cc"
    break;

  case 178: /* statement: K_TRANIF1 T_SYMBOL ',' T_SYMBOL T_SYMBOL ',' T_SYMBOL ';'  */
#line 895 "parse.y"
      { compile_island_tranif(1, (yyvsp[-6].text), (yyvsp[-4].text), (yyvsp[-3].text), (yyvsp[-1].text), 0); }
#line 3166 "parse.cc"
    break;

  case 179: /* statement: K_TRANVP T_NUMBER T_NUMBER T_NUMBER ',' T_SYMBOL ',' T_SYMBOL T_SYMBOL ';'  */
#line 898 "parse.y"
      { compile_island_tranvp((yyvsp[-4].text), (yyvsp[-2].text), (yyvsp[-1].text), (yyvsp[-8].numb), (yyvsp[-7].numb), (yyvsp[-6].numb)); }
#line 3172 "parse.cc"
    break;

  case 180: /* $@3: %empty  */
#line 903 "parse.y"
      { compile_class_start((yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].numb)); }
#line 3178 "parse.cc"
    break;

  case 181: /* statement: T_LABEL K_CLASS T_STRING '[' T_NUMBER ']' $@3 class_properties_opt ';'  */
#line 905 "parse.y"
      { compile_class_done(); }
#line 3184 "parse.cc"
    break;

  case 182: /* statement: enum_type  */
#line 908 "parse.y"
      { ; }
#line 3190 "parse.cc"
    break;

  case 188: /* class_property: T_NUMBER ':' T_STRING ',' T_STRING dimensions_opt  */
#line 927 "parse.y"
      { compile_class_property((yyvsp[-5].numb), (yyvsp[-3].text), (yyvsp[-1].text), (yyvsp[0].numb)); }
#line 3196 "parse.cc"
    break;

  case 189: /* dimensions_opt: dimensions  */
#line 938 "parse.y"
      { (yyval.numb) = (yyvsp[0].numb); }
#line 3202 "parse.cc"
    break;

  case 190: /* dimensions_opt: %empty  */
#line 939 "parse.y"
      { (yyval.numb) = 0; }
#line 3208 "parse.cc"
    break;

  case 191: /* dimensions: dimensions dimension  */
#line 944 "parse.y"
      { (yyval.numb) = (yyvsp[-1].numb) * (yyvsp[0].numb); }
#line 3214 "parse.cc"
    break;

  case 192: /* dimensions: dimension  */
#line 946 "parse.y"
      { (yyval.numb) = (yyvsp[0].numb); }
#line 3220 "parse.cc"
    break;

  case 193: /* dimension: '[' T_NUMBER ':' T_NUMBER ']'  */
#line 951 "parse.y"
      { (yyval.numb) = ((yyvsp[-3].numb) > (yyvsp[-1].numb)? (yyvsp[-3].numb) - (yyvsp[-1].numb) : (yyvsp[-1].numb) - (yyvsp[-3].numb)) + 1; }
#line 3226 "parse.cc"
    break;

  case 194: /* enum_type: T_LABEL K_ENUM2 '(' T_NUMBER ')' enum_type_names ';'  */
#line 957 "parse.y"
      { compile_enum2_type((yyvsp[-6].text), (yyvsp[-3].numb), false, (yyvsp[-1].enum_namev)); }
#line 3232 "parse.cc"
    break;

  case 195: /* enum_type: T_LABEL K_ENUM2_S '(' T_NUMBER ')' enum_type_names ';'  */
#line 959 "parse.y"
      { compile_enum2_type((yyvsp[-6].text), (yyvsp[-3].numb), true, (yyvsp[-1].enum_namev)); }
#line 3238 "parse.cc"
    break;

  case 196: /* enum_type: T_LABEL K_ENUM4 '(' T_NUMBER ')' enum_type_names ';'  */
#line 961 "parse.y"
      { compile_enum4_type((yyvsp[-6].text), (yyvsp[-3].numb), false, (yyvsp[-1].enum_namev)); }
#line 3244 "parse.cc"
    break;

  case 197: /* enum_type: T_LABEL K_ENUM4_S '(' T_NUMBER ')' enum_type_names ';'  */
#line 963 "parse.y"
      { compile_enum4_type((yyvsp[-6].text), (yyvsp[-3].numb), true, (yyvsp[-1].enum_namev)); }
#line 3250 "parse.cc"
    break;

  case 198: /* enum_type_names: enum_type_name  */
#line 968 "parse.y"
      { list<struct enum_name_s>*tmp = new list<struct enum_name_s>;
	tmp->push_back((yyvsp[0].enum_name));
	(yyval.enum_namev) = tmp;
      }
#line 3259 "parse.cc"
    break;

  case 199: /* enum_type_names: enum_type_names ',' enum_type_name  */
#line 973 "parse.y"
      { list<struct enum_name_s>*tmp = (yyvsp[-2].enum_namev);
	tmp->push_back((yyvsp[0].enum_name));
	(yyval.enum_namev) = tmp;
      }
#line 3268 "parse.cc"
    break;

  case 200: /* enum_type_name: T_STRING T_NUMBER  */
#line 981 "parse.y"
      { (yyval.enum_name).text = (yyvsp[-1].text); (yyval.enum_name).val2 = (yyvsp[0].numb); (yyval.enum_name).val4 = 0; }
#line 3274 "parse.cc"
    break;

  case 201: /* enum_type_name: T_STRING T_VECTOR  */
#line 983 "parse.y"
      { (yyval.enum_name).text = (yyvsp[-1].text); (yyval.enum_name).val2 = 0; (yyval.enum_name).val4 = (yyvsp[0].vect).text; }
#line 3280 "parse.cc"
    break;

  case 202: /* local_flag: '*'  */
#line 987 "parse.y"
        { (yyval.flag) = true; }
#line 3286 "parse.cc"
    break;

  case 203: /* local_flag: %empty  */
#line 988 "parse.y"
        { (yyval.flag) = false; }
#line 3292 "parse.cc"
    break;

  case 204: /* label_opt: T_LABEL  */
#line 995 "parse.y"
                  { (yyval.text) = (yyvsp[0].text); }
#line 3298 "parse.cc"
    break;

  case 205: /* label_opt: %empty  */
#line 996 "parse.y"
                  { (yyval.text) = 0; }
#line 3304 "parse.cc"
    break;

  case 206: /* operands_opt: operands  */
#line 1000 "parse.y"
                   { (yyval.opa) = (yyvsp[0].opa); }
#line 3310 "parse.cc"
    break;

  case 207: /* operands_opt: %empty  */
#line 1001 "parse.y"
                   { (yyval.opa) = 0; }
#line 3316 "parse.cc"
    break;

  case 208: /* operands: operands ',' operand  */
#line 1006 "parse.y"
                { comp_operands_t opa = (yyvsp[-2].opa);
		  assert(opa->argc < 3);
		  assert((yyvsp[0].opa)->argc == 1);
		  opa->argv[opa->argc] = (yyvsp[0].opa)->argv[0];
		  opa->argc += 1;
		  free((yyvsp[0].opa));
		  (yyval.opa) =  opa;
		}
#line 3329 "parse.cc"
    break;

  case 209: /* operands: operand  */
#line 1015 "parse.y"
                { (yyval.opa) = (yyvsp[0].opa); }
#line 3335 "parse.cc"
    break;

  case 210: /* operand: symbol  */
#line 1020 "parse.y"
      { comp_operands_t opa = static_cast<comp_operands_t>
                                         (calloc(1, sizeof(struct comp_operands_s)));
	opa->argc = 1;
	opa->argv[0].ltype = L_SYMB;
	opa->argv[0].symb = (yyvsp[0].symb);
	(yyval.opa) = opa;
      }
#line 3347 "parse.cc"
    break;

  case 211: /* operand: T_NUMBER  */
#line 1028 "parse.y"
      { comp_operands_t opa = static_cast<comp_operands_t>
                                         (calloc(1, sizeof(struct comp_operands_s)));
	opa->argc = 1;
	opa->argv[0].ltype = L_NUMB;
	opa->argv[0].numb = (yyvsp[0].numb);
	(yyval.opa) = opa;
      }
#line 3359 "parse.cc"
    break;

  case 212: /* operand: T_STRING  */
#line 1036 "parse.y"
      { comp_operands_t opa = static_cast<comp_operands_t>
                                         (calloc(1, sizeof(struct comp_operands_s)));
	opa->argc = 1;
	opa->argv[0].ltype = L_STRING;
	opa->argv[0].text = (yyvsp[0].text);
	(yyval.opa) = opa;
      }
#line 3371 "parse.cc"
    break;

  case 213: /* argument_opt: ',' argument_list  */
#line 1061 "parse.y"
                {
		  argv_sym_lookup(&(yyvsp[0].argv));
		  (yyval.argv) = (yyvsp[0].argv);
		}
#line 3380 "parse.cc"
    break;

  case 214: /* argument_opt: %empty  */
#line 1066 "parse.y"
                { struct argv_s tmp;
		  argv_init(&tmp);
		  (yyval.argv) = tmp;
		}
#line 3389 "parse.cc"
    break;

  case 215: /* argument_list: argument  */
#line 1074 "parse.y"
      { struct argv_s tmp;
	argv_init(&tmp);
	argv_add(&tmp, (yyvsp[0].vpi));
	(yyval.argv) = tmp;
      }
#line 3399 "parse.cc"
    break;

  case 216: /* argument_list: argument_list ',' argument  */
#line 1080 "parse.y"
      { struct argv_s tmp = (yyvsp[-2].argv);
	argv_add(&tmp, (yyvsp[0].vpi));
	(yyval.argv) = tmp;
      }
#line 3408 "parse.cc"
    break;

  case 217: /* argument_list: T_SYMBOL  */
#line 1085 "parse.y"
      { struct argv_s tmp;
	argv_init(&tmp);
	argv_sym_add(&tmp, (yyvsp[0].text));
	(yyval.argv) = tmp;
      }
#line 3418 "parse.cc"
    break;

  case 218: /* argument_list: argument_list ',' T_SYMBOL  */
#line 1091 "parse.y"
      { struct argv_s tmp = (yyvsp[-2].argv);
	argv_sym_add(&tmp, (yyvsp[0].text));
	(yyval.argv) = tmp;
      }
#line 3427 "parse.cc"
    break;

  case 219: /* argument: T_STRING  */
#line 1099 "parse.y"
      { (yyval.vpi) = vpip_make_string_const((yyvsp[0].text)); }
#line 3433 "parse.cc"
    break;

  case 220: /* argument: T_VECTOR  */
#line 1101 "parse.y"
      { (yyval.vpi) = vpip_make_binary_const((yyvsp[0].vect).idx, (yyvsp[0].vect).text);
	free((yyvsp[0].vect).text);
      }
#line 3441 "parse.cc"
    break;

  case 221: /* argument: symbol_access  */
#line 1105 "parse.y"
      { (yyval.vpi) = (yyvsp[0].vpi); }
#line 3447 "parse.cc"
    break;

  case 222: /* symbol_access: K_A '<' T_SYMBOL ',' T_NUMBER '>'  */
#line 1110 "parse.y"
      { (yyval.vpi) = vpip_make_vthr_A((yyvsp[-3].text), (yyvsp[-1].numb)); }
#line 3453 "parse.cc"
    break;

  case 223: /* symbol_access: K_A '<' T_SYMBOL ',' T_SYMBOL '>'  */
#line 1112 "parse.y"
      { (yyval.vpi) = vpip_make_vthr_A((yyvsp[-3].text), (yyvsp[-1].text)); }
#line 3459 "parse.cc"
    break;

  case 224: /* symbol_access: K_A '<' T_SYMBOL ',' symbol_access '>'  */
#line 1114 "parse.y"
      { (yyval.vpi) = vpip_make_vthr_A((yyvsp[-3].text), (yyvsp[-1].vpi)); }
#line 3465 "parse.cc"
    break;

  case 225: /* symbol_access: K_PV '<' T_SYMBOL ',' T_NUMBER ',' T_NUMBER '>'  */
#line 1116 "parse.y"
      { (yyval.vpi) = vpip_make_PV((yyvsp[-5].text), (yyvsp[-3].numb), (yyvsp[-1].numb)); }
#line 3471 "parse.cc"
    break;

  case 226: /* symbol_access: K_PV '<' T_SYMBOL ',' '-' T_NUMBER ',' T_NUMBER '>'  */
#line 1118 "parse.y"
      { (yyval.vpi) = vpip_make_PV((yyvsp[-6].text), -(yyvsp[-3].numb), (yyvsp[-1].numb)); }
#line 3477 "parse.cc"
    break;

  case 227: /* symbol_access: K_PV '<' T_SYMBOL ',' T_SYMBOL ',' T_NUMBER '>'  */
#line 1120 "parse.y"
      { (yyval.vpi) = vpip_make_PV((yyvsp[-5].text), (yyvsp[-3].text), (yyvsp[-1].numb)); }
#line 3483 "parse.cc"
    break;

  case 228: /* symbol_access: K_PV '<' T_SYMBOL ',' symbol_access ',' T_NUMBER '>'  */
#line 1122 "parse.y"
      { (yyval.vpi) = vpip_make_PV((yyvsp[-5].text), (yyvsp[-3].vpi), (yyvsp[-1].numb)); }
#line 3489 "parse.cc"
    break;

  case 229: /* symbol_access: K_APV '<' T_SYMBOL ',' T_NUMBER ',' T_NUMBER ',' T_NUMBER '>'  */
#line 1124 "parse.y"
      { (yyval.vpi) = vpip_make_vthr_APV((yyvsp[-7].text), (yyvsp[-5].numb), (yyvsp[-3].numb), (yyvsp[-1].numb)); }
#line 3495 "parse.cc"
    break;

  case 230: /* symbols: symbol  */
#line 1130 "parse.y"
                { struct symbv_s obj;
		  symbv_init(&obj);
		  symbv_add(&obj, (yyvsp[0].symb));
		  (yyval.symbv) = obj;
		}
#line 3505 "parse.cc"
    break;

  case 231: /* symbols: symbols ',' symbol  */
#line 1136 "parse.y"
                { struct symbv_s obj = (yyvsp[-2].symbv);
		  symbv_add(&obj, (yyvsp[0].symb));
		  (yyval.symbv) = obj;
		}
#line 3514 "parse.cc"
    break;

  case 232: /* numbers: T_NUMBER  */
#line 1145 "parse.y"
                { struct numbv_s obj;
		  numbv_init(&obj);
		  numbv_add(&obj, (yyvsp[0].numb));
		  (yyval.numbv) = obj;
		}
#line 3524 "parse.cc"
    break;

  case 233: /* numbers: numbers ',' T_NUMBER  */
#line 1151 "parse.y"
                { struct numbv_s obj = (yyvsp[-2].numbv);
		  numbv_add(&obj, (yyvsp[0].numb));
		  (yyval.numbv) = obj;
		}
#line 3533 "parse.cc"
    break;

  case 234: /* symbols_net: symbol_opt  */
#line 1160 "parse.y"
                { struct symbv_s obj;
		  symbv_init(&obj);
		  symbv_add(&obj, (yyvsp[0].symb));
		  (yyval.symbv) = obj;
		}
#line 3543 "parse.cc"
    break;

  case 235: /* symbols_net: symbols_net ',' symbol_opt  */
#line 1166 "parse.y"
                { struct symbv_s obj = (yyvsp[-2].symbv);
		  symbv_add(&obj, (yyvsp[0].symb));
		  (yyval.symbv) = obj;
		}
#line 3552 "parse.cc"
    break;

  case 236: /* symbol: T_SYMBOL  */
#line 1178 "parse.y"
                { (yyval.symb).text = (yyvsp[0].text);
		  (yyval.symb).idx = 0;
		}
#line 3560 "parse.cc"
    break;

  case 237: /* symbol_opt: symbol  */
#line 1185 "parse.y"
                { (yyval.symb) = (yyvsp[0].symb); }
#line 3566 "parse.cc"
    break;

  case 238: /* symbol_opt: %empty  */
#line 1187 "parse.y"
                { (yyval.symb).text = 0;
		  (yyval.symb).idx = 0;
		}
#line 3574 "parse.cc"
    break;

  case 241: /* port_type: K_PORT_INPUT  */
#line 1202 "parse.y"
                       { (yyval.vpi_enum) = vpiInput; }
#line 3580 "parse.cc"
    break;

  case 242: /* port_type: K_PORT_OUTPUT  */
#line 1203 "parse.y"
                        { (yyval.vpi_enum) = vpiOutput; }
#line 3586 "parse.cc"
    break;

  case 243: /* port_type: K_PORT_INOUT  */
#line 1204 "parse.y"
                        { (yyval.vpi_enum) = vpiInout; }
#line 3592 "parse.cc"
    break;

  case 244: /* port_type: K_PORT_MIXED  */
#line 1205 "parse.y"
                        { (yyval.vpi_enum) = vpiMixedIO; }
#line 3598 "parse.cc"
    break;

  case 245: /* port_type: K_PORT_NODIR  */
#line 1206 "parse.y"
                        { (yyval.vpi_enum) = vpiNoDirection; }
#line 3604 "parse.cc"
    break;

  case 246: /* modpath_src: symbol '(' numbers ')' symbol  */
#line 1211 "parse.y"
      { compile_modpath_src(modpath_dst, 0, (yyvsp[-4].symb), (yyvsp[-2].numbv), 0, (yyvsp[0].symb), false); }
#line 3610 "parse.cc"
    break;

  case 247: /* modpath_src: symbol '(' numbers '?' ')' symbol  */
#line 1213 "parse.y"
      { compile_modpath_src(modpath_dst, 0, (yyvsp[-5].symb), (yyvsp[-3].numbv), 0, (yyvsp[0].symb), true); }
#line 3616 "parse.cc"
    break;

  case 248: /* modpath_src: symbol '(' numbers '?' symbol ')' symbol  */
#line 1215 "parse.y"
      { compile_modpath_src(modpath_dst, 0, (yyvsp[-6].symb), (yyvsp[-4].numbv), (yyvsp[-2].symb), (yyvsp[0].symb)); }
#line 3622 "parse.cc"
    break;

  case 249: /* modpath_src: symbol '+' '(' numbers ')' symbol  */
#line 1217 "parse.y"
      { compile_modpath_src(modpath_dst, '+', (yyvsp[-5].symb), (yyvsp[-2].numbv), 0, (yyvsp[0].symb), false); }
#line 3628 "parse.cc"
    break;

  case 250: /* modpath_src: symbol '+' '(' numbers '?' ')' symbol  */
#line 1219 "parse.y"
      { compile_modpath_src(modpath_dst, '+', (yyvsp[-6].symb), (yyvsp[-3].numbv), 0, (yyvsp[0].symb), true); }
#line 3634 "parse.cc"
    break;

  case 251: /* modpath_src: symbol '+' '(' numbers '?' symbol ')' symbol  */
#line 1221 "parse.y"
      { compile_modpath_src(modpath_dst, '+', (yyvsp[-7].symb), (yyvsp[-4].numbv), (yyvsp[-2].symb), (yyvsp[0].symb)); }
#line 3640 "parse.cc"
    break;

  case 252: /* modpath_src: symbol '-' '(' numbers ')' symbol  */
#line 1223 "parse.y"
      { compile_modpath_src(modpath_dst, '-', (yyvsp[-5].symb), (yyvsp[-2].numbv), 0, (yyvsp[0].symb), false); }
#line 3646 "parse.cc"
    break;

  case 253: /* modpath_src: symbol '-' '(' numbers '?' ')' symbol  */
#line 1225 "parse.y"
      { compile_modpath_src(modpath_dst, '-', (yyvsp[-6].symb), (yyvsp[-3].numbv), 0, (yyvsp[0].symb), true); }
#line 3652 "parse.cc"
    break;

  case 254: /* modpath_src: symbol '-' '(' numbers '?' symbol ')' symbol  */
#line 1227 "parse.y"
      { compile_modpath_src(modpath_dst, '-', (yyvsp[-7].symb), (yyvsp[-4].numbv), (yyvsp[-2].symb), (yyvsp[0].symb)); }
#line 3658 "parse.cc"
    break;

  case 255: /* udp_table: T_STRING  */
#line 1232 "parse.y"
                { (yyval.table) = compile_udp_table(0x0, (yyvsp[0].text)); }
#line 3664 "parse.cc"
    break;

  case 256: /* udp_table: udp_table ',' T_STRING  */
#line 1234 "parse.y"
                { (yyval.table) = compile_udp_table((yyvsp[-2].table),  (yyvsp[0].text)); }
#line 3670 "parse.cc"
    break;

  case 257: /* signed_t_number: T_NUMBER  */
#line 1238 "parse.y"
                       { (yyval.numb) = (yyvsp[0].numb); }
#line 3676 "parse.cc"
    break;

  case 258: /* signed_t_number: '-' T_NUMBER  */
#line 1239 "parse.y"
                       { (yyval.numb) = -(yyvsp[0].numb); }
#line 3682 "parse.cc"
    break;

  case 259: /* delay: '(' T_NUMBER ')'  */
#line 1244 "parse.y"
                { (yyval.cdelay) = new vvp_delay_t((yyvsp[-1].numb), (yyvsp[-1].numb)); }
#line 3688 "parse.cc"
    break;

  case 260: /* delay: '(' T_NUMBER ',' T_NUMBER ')'  */
#line 1246 "parse.y"
                { (yyval.cdelay) = new vvp_delay_t((yyvsp[-3].numb), (yyvsp[-1].numb)); }
#line 3694 "parse.cc"
    break;

  case 261: /* delay: '(' T_NUMBER ',' T_NUMBER ',' T_NUMBER ')'  */
#line 1248 "parse.y"
                { (yyval.cdelay) = new vvp_delay_t((yyvsp[-5].numb), (yyvsp[-3].numb), (yyvsp[-1].numb)); }
#line 3700 "parse.cc"
    break;


#line 3704 "parse.cc"

      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", YY_CAST (yysymbol_kind_t, yyr1[yyn]), &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */
  {
    const int yylhs = yyr1[yyn] - YYNTOKENS;
    const int yyi = yypgoto[yylhs] + *yyssp;
    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
               ? yytable[yyi]
               : yydefgoto[yylhs]);
  }

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
      yyerror (YY_("syntax error"));
    }

  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= YYEOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == YYEOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval);
          yychar = YYEMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:
  /* Pacify compilers when the user code never invokes YYERROR and the
     label yyerrorlab therefore never appears in user code.  */
  if (0)
    YYERROR;
  ++yynerrs;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  /* Pop stack until we find a state that shifts the error token.  */
  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYSYMBOL_YYerror;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYSYMBOL_YYerror)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  YY_ACCESSING_SYMBOL (yystate), yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", YY_ACCESSING_SYMBOL (yyn), yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturnlab;


/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturnlab;


/*-----------------------------------------------------------.
| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
`-----------------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  goto yyreturnlab;


/*----------------------------------------------------------.
| yyreturnlab -- parsing is finished, clean up and return.  |
`----------------------------------------------------------*/
yyreturnlab:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  YY_ACCESSING_SYMBOL (+*yyssp), yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif

  return yyresult;
}

#line 1251 "parse.y"


int compile_design(const char*path)
{
      yypath = path;
      yyline = 1;
      yyin = fopen(path, "r");
      if (yyin == 0) {
	    fprintf(stderr, "%s: Unable to open input file.\n", path);
	    return -1;
      }

      int rc = yyparse();
      fclose(yyin);
      return rc;
}
